@@ -9,9 +9,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250605.2
+script_version=20251113.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='age-of-mythology'
 GAME_NAME='Age of Mythology'
@@ -27,13 +27,24 @@ ARCHIVE_BASE_DEMO_0_VERSION='1.0-archiveorg1'
 ARCHIVE_BASE_DEMO_0_URL='https://archive.org/details/AgeOfMythologyDemo'
 
 CONTENT_PATH_DEFAULT='aom'
+## aom.exe requirements
+CONTENT_LIBS_BIN_FILES='
+RockallDLL.dll
+granny.dll
+mss32.dll'
+## moviePlayer.exe requirements
+CONTENT_LIBS0_BIN_FILES='
+binkw32.dll'
+## The game fails to start if the following library is missing.
+CONTENT_LIBS1_BIN_PATH='.'
+CONTENT_LIBS1_BIN_FILES='
+EBUEula.dll'
+## Text is wrongly displayed if the following library is missing.
+CONTENT_LIBS2_BIN_FILES='
+language.dll'
 CONTENT_GAME_BIN_FILES='
 mp3dec.asi
-*.exe
-*.dll'
-CONTENT_GAME0_BIN_PATH='.'
-CONTENT_GAME0_BIN_FILES='
-*.dll'
+*.exe'
 CONTENT_FONTS_DATA_FILES='
 arialuni.ttf
 gio_bk.ttf
@@ -62,9 +73,6 @@ sound
 startup
 textures
 trigger
-10??
-20??
-30??
 *.bmp'
 CONTENT_DOC_DATA_PATH='.'
 CONTENT_DOC_DATA_FILES='
@@ -84,10 +92,6 @@ savegame
 screenshots
 users'
 
-## Without a virtual desktop,
-## keyboard input is lost on loss of focus.
-WINE_VIRTUAL_DESKTOP='1600x1200'
-
 APP_MAIN_EXE='aom.exe'
 
 PACKAGES_LIST='
@@ -128,66 +132,26 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
+
+# Rename files with truncated names.
+
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Rename files with truncated names.
+	## Shipped libraries
+	mv 'rockal_1.dll' 'rockalldll.dll'
+
 	mv 'gfxcon_1' 'gfxconfig'
 	mv 'godpow_1' 'god powers'
 	mv 'sound/cinema_1' 'sound/cinematics'
 	mv 'sound/music/interf_1' 'sound/music/interface'
-	mv '1028/dwin0000.dll' '1028/dwintl.dll'
-	mv '1029/dwin0001.dll' '1029/dwintl.dll'
-	mv '1030/dwin0002.dll' '1030/dwintl.dll'
-	mv '1031/dwin0003.dll' '1031/dwintl.dll'
-	mv '1031/msil0000.bin' '1031/msiloadr.bin'
-	mv '1031/webl0000.bin' '1031/webloadr.bin'
-	mv '1032/dwin0004.dll' '1032/dwintl.dll'
-	mv '1033/dwin0005.dll' '1033/dwintl.dll'
-	mv '1033/msil0001.bin' '1033/msiloadr.bin'
-	mv '1033/webl0001.bin' '1033/webloadr.bin'
-	mv '1035/dwin0006.dll' '1035/dwintl.dll'
-	mv '1036/dwin0007.dll' '1036/dwintl.dll'
-	mv '1036/msil0002.bin' '1036/msiloadr.bin'
-	mv '1036/webl0002.bin' '1036/webloadr.bin'
-	mv '1037/dwin0008.dll' '1037/dwintl.dll'
-	mv '1038/dwin0009.dll' '1038/dwintl.dll'
-	mv '1040/dwin000a.dll' '1040/dwintl.dll'
-	mv '1040/msil0003.bin' '1040/msiloadr.bin'
-	mv '1040/webl0003.bin' '1040/webloadr.bin'
-	mv '1041/dwin000b.dll' '1041/dwintl.dll'
-	mv '1041/msil0004.bin' '1041/msiloadr.bin'
-	mv '1041/webl0004.bin' '1041/webloadr.bin'
-	mv '1042/dwin000c.dll' '1042/dwintl.dll'
-	mv '1042/msil0005.bin' '1042/msiloadr.bin'
-	mv '1042/webl0005.bin' '1042/webloadr.bin'
-	mv '1043/dwin000d.dll' '1043/dwintl.dll'
-	mv '1044/dwin000e.dll' '1044/dwintl.dll'
-	mv '1045/dwin000f.dll' '1045/dwintl.dll'
-	mv '1046/dwin0010.dll' '1046/dwintl.dll'
-	mv '1048/dwin0011.dll' '1048/dwintl.dll'
-	mv '1049/dwin0012.dll' '1049/dwintl.dll'
-	mv '1050/dwin0013.dll' '1050/dwintl.dll'
-	mv '1051/dwin0014.dll' '1051/dwintl.dll'
-	mv '1053/dwin0015.dll' '1053/dwintl.dll'
-	mv '1054/dwin0016.dll' '1054/dwintl.dll'
-	mv '1055/dwin0017.dll' '1055/dwintl.dll'
-	mv '1060/dwin0018.dll' '1060/dwintl.dll'
-	mv '2052/dwin0019.dll' '2052/dwintl.dll'
-	mv '2052/msil0006.bin' '2052/msiloadr.bin'
-	mv '2052/webl0006.bin' '2052/webloadr.bin'
-	mv '2070/dwin001a.dll' '2070/dwintl.dll'
-	mv '3076/dwin001b.dll' '3076/dwintl.dll'
-	mv '3082/dwin001c.dll' '3082/dwintl.dll'
-	mv '3082/msil0007.bin' '3082/msiloadr.bin'
-	mv '3082/webl0007.bin' '3082/webloadr.bin'
 	mv 'ai/ao9982_1.xs' 'ai/aomdefaultaiprogress.xs'
 	mv 'ai/aomdef_1.xs' 'ai/aomdefaultai.xs'
 	mv 'ai/aomdef_2.xs' 'ai/aomdefaultaieconomy.xs'
@@ -216,7 +180,6 @@ archive_extraction_default
 	mv 'docs/aomsta_1.pdf' 'docs/aomstandard_manual_en.pdf'
 	mv 'docs/troubl_1.rtf' 'docs/troubleshooting crashing issues.rtf'
 	mv 'docs/troubl_2.rtf' 'docs/troubleshooting display problems.rtf'
-	mv 'esocli_1.dll' 'esoclientdll.dll'
 	mv 'fonts/arialu_1.msk' 'fonts/arial unicode ms.msk'
 	mv 'fonts/courie_1.msk' 'fonts/courier new.msk'
 	mv 'fonts/frizqu_1.msk' 'fonts/friz quadrata tt.msk'
@@ -803,7 +766,6 @@ archive_extraction_default
 	mv 'rm/vinlan_1.xs' 'rm/vinlandsaga.xs'
 	mv 'rm/wateri_1.xml' 'rm/watering hole.xml'
 	mv 'rm/wateri_1.xs' 'rm/watering hole.xs'
-	mv 'rockal_1.dll' 'rockalldll.dll'
 	mv 'rts3ba_1.txt' 'rts3banglog.txt'
 	mv 'scenario/scenar_1.bar' 'scenario/scenarios.bar'
 	mv 'sound/aheroh_1.wav' 'sound/aherohasfallen.wav'
@@ -927,19 +889,26 @@ archive_extraction_default
 	mv 'textures/cursors/scbed3_1.cur' 'textures/cursors/scale_vert cursor mono.cur'
 	mv 'trigger/basicv_1.xs' 'trigger/basicvcnomain.xs'
 	mv 'trigger/rmsudd_1.xs' 'trigger/rmsuddendeathvc.xs'
-	mv 'zoneac_1.dll' 'zoneaccessapi.dll'
 )
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
