@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Alpha Centauri
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241123.1
+script_version=20250318.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='alpha-centauri'
 GAME_NAME='Alpha Centauri'
@@ -181,17 +182,10 @@ PKG_MOVIES_DESCRIPTION='movies'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PRELOAD_HACKS_LIST='
-HACK_SDL1COMPAT'
-
 # LD_PRELOAD shim allowing the old engine to run on top of latest SDL1 library
 # cf. https://github.com/ZeroPointEnergy/smacshim
 
-HACK_SDL1COMPAT_NAME='smacshim'
-HACK_SDL1COMPAT_DESCRIPTION='LD_PRELOAD shim allowing the old engine to run on top of latest SDL1 library
-cf. https://github.com/ZeroPointEnergy/smacshim'
-HACK_SDL1COMPAT_PACKAGE='PKG_BIN'
-HACK_SDL1COMPAT_SOURCE='
+LD_PRELOAD_SOURCE='
 #define _GNU_SOURCE
 
 #include <stdio.h>
@@ -276,10 +270,6 @@ if [ -z "${RENAME_CMD:-}" ]; then
 	exit 1
 fi
 
-# Build and include the LD_PRELOAD shim required for the old engine to run on top of modern libraries
-
-hacks_inclusion_default
-
 # Extract game data
 
 archive_extraction_default
