@@ -9,9 +9,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241227.1
+script_version=20251113.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='anachronox'
 GAME_NAME='Anachronox'
@@ -31,33 +31,52 @@ ARCHIVE_BASE_0_VERSION='1.02-gog2.0.0.28'
 
 CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_0='app'
-CONTENT_GAME_BIN_FILES='
-anoxdata/miles
-anoxdata/plugins
+## anox.exe requirements
+CONTENT_LIBS_BIN_FILES='
 anoxaux.dll
 anoxgfx.dll
 gamex86.dll
-ijl15.dll
-libpng13a.dll
-metagl.dll
-mss32.dll
-msvcp60.dll
-msvcrt.dll
-patch.dll
+PATCH.dll
 ref_gl.dll
-zlib.dll
-afscmd.exe
-anox.exe
-autorun.exe
-dparse.exe
-gct setup.exe
-particleman.exe
-setupanox.exe
-autorun.inf
-gct setup.ini
-mscomctl.ocx'
+zlib.dll'
+## anoxgfx.dll requirements
+CONTENT_LIBS0_BIN_FILES='
+libpng13a.dll'
+## The game crashes when trying to play the logo video without this library.
+CONTENT_LIBS1_BIN_FILES='
+anoxdata/plugins/anoxsnd.dll'
+## anoxdata/plugins/anoxsnd.dll requirements
+CONTENT_LIBS2_BIN_FILES='
+mss32.dll'
+## The game fails to render the menu without this library.
+CONTENT_LIBS3_BIN_FILES='
+anoxdata/plugins/ui.dll'
+## anoxdata/plugins/ui.dll requirements
+CONTENT_LIBS4_BIN_FILES='
+anoxdata/plugins/NOXGAME.dll
+anoxdata/plugins/PLANET.dll'
+## The player model is not displayed and sound effects are not played without this library.
+CONTENT_LIBS5_BIN_FILES='
+anoxdata/plugins/camera.dll'
+## Items can not be picked up without this library.
+CONTENT_LIBS6_BIN_FILES='
+anoxdata/plugins/intellinox.dll'
+CONTENT_GAME_BIN_FILES='
+anoxdata/miles/mp3dec.asi
+anoxdata/miles/*.m3d
+anoxdata/plugins/dllorder.txt
+anox.exe'
 CONTENT_GAME_DATA_FILES='
-anoxdata
+anoxdata/configs
+anoxdata/gameflow
+anoxdata/graphics
+anoxdata/models
+anoxdata/music
+anoxdata/save
+anoxdata/sound
+anoxdata/version.anox
+anoxdata/anox1.zip
+anoxdata/*.dat
 anox.ico
 anachronox_word.jpg'
 CONTENT_DOC_DATA_FILES='
@@ -69,7 +88,6 @@ anachronox patch 1_02.rtf
 USER_PERSISTENT_DIRECTORIES='
 anoxdata/save'
 USER_PERSISTENT_FILES='
-*.ini
 anoxdata/nokill.*'
 
 APP_MAIN_EXE='anox.exe'
@@ -86,7 +104,7 @@ PKG_DATA'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -112,29 +130,44 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
