@@ -8,18 +8,23 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20251015.1
+script_version=20251113.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='ballisticng'
 GAME_NAME='BallisticNG'
 
+ARCHIVE_BASE_3_NAME='ballisticng_1_4_1_86271.sh'
+ARCHIVE_BASE_3_MD5='e50a92e232d519ba942e79c8b98652e4'
+ARCHIVE_BASE_3_SIZE='3430475'
+ARCHIVE_BASE_3_VERSION='1.4.1-gog86271'
+ARCHIVE_BASE_3_URL='https://www.gog.com/game/ballisticng'
+
 ARCHIVE_BASE_2_NAME='ballisticng_1_4_0_1b_81954.sh'
 ARCHIVE_BASE_2_MD5='3adf1cbf124a48baccb987473eec85ea'
 ARCHIVE_BASE_2_SIZE='3381101'
 ARCHIVE_BASE_2_VERSION='1.4.0.1b-gog81954'
-ARCHIVE_BASE_2_URL='https://www.gog.com/game/ballisticng'
 
 ARCHIVE_BASE_1_NAME='ballisticng_1_4_0_1_81860.sh'
 ARCHIVE_BASE_1_MD5='beedfb6afab94fc66783c12b805876df'
@@ -42,9 +47,6 @@ UNITY3D_PLUGINS="$UNITY3D_PLUGINS
 libsteam_api.so"
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
-CONTENT_GAME0_BIN_FILES='
-DedicatedServerExample.cfg
-SvrScripts'
 CONTENT_GAME_EXPANSION_TRACKS_FILES='
 DLC/free extra tracks.cpd
 DLC/free extra tracks.cps'
@@ -57,16 +59,6 @@ Legacy Track Creator Commands.txt'
 
 USER_PERSISTENT_DIRECTORIES='
 User'
-USER_PERSISTENT_FILES='
-DedicatedServerExample.cfg'
-
-APPLICATIONS_LIST='
-APP_MAIN
-APP_SERVER'
-
-APP_SERVER_ID="${GAME_ID}-server"
-APP_SERVER_NAME="$GAME_NAME - Server"
-APP_SERVER_OPTIONS='-batchmode -nographics -logfile -svrcfg DedicatedServerExample.cfg'
 
 PACKAGES_LIST='
 PKG_BIN
