@@ -12,9 +12,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250531.1
+script_version=20260913.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='darkest-dungeon'
 GAME_NAME='Darkest Dungeon'
@@ -35,13 +35,17 @@ EXPANSION_NAME_COLOROFMADNESS='The Color of Madness'
 
 ## Musketeer
 
-## This build is the one provided by GOG since 2025-05-29,
-## but it is an old build from 2018.
+ARCHIVE_BASE_MUSKETEER_7_NAME='darkest_dungeon_musketeer_26186c_83747.sh'
+ARCHIVE_BASE_MUSKETEER_7_MD5='57cdcc137b92c2b1d3a07816be0f13f0'
+ARCHIVE_BASE_MUSKETEER_7_SIZE='20500'
+ARCHIVE_BASE_MUSKETEER_7_VERSION='26186c-gog83747'
+ARCHIVE_BASE_MUSKETEER_7_URL='https://www.gog.com/game/darkest_dungeon_musketeer'
+
+## This build is the one provided by GOG since 2025-05-29, but it is an old build from 2018.
 ARCHIVE_BASE_MUSKETEER_6_NAME='darkest_dungeon_musketeer_24788_82473.sh'
 ARCHIVE_BASE_MUSKETEER_6_MD5='3af92d89c085c91d7e654da2171c70a8'
 ARCHIVE_BASE_MUSKETEER_6_SIZE='20500'
 ARCHIVE_BASE_MUSKETEER_6_VERSION='24788-gog82473'
-ARCHIVE_BASE_MUSKETEER_6_URL='https://www.gog.com/game/darkest_dungeon_musketeer'
 
 ARCHIVE_BASE_MUSKETEER_5_NAME='darkest_dungeon_musketeer_26186_81633.sh'
 ARCHIVE_BASE_MUSKETEER_5_MD5='c7f10e04a57302b89f6793768f9fc1de'
@@ -75,13 +79,17 @@ ARCHIVE_BASE_MUSKETEER_0_VERSION='23885-gog21662'
 
 ## The Crimson Court
 
-## This build is the one provided by GOG since 2025-05-29,
-## but it is an old build from 2018.
+ARCHIVE_BASE_CRIMSONCOURT_10_NAME='darkest_dungeon_the_crimson_court_26186c_83747.sh'
+ARCHIVE_BASE_CRIMSONCOURT_10_MD5='7a1fc1515fb35f16837147f8588adc38'
+ARCHIVE_BASE_CRIMSONCOURT_10_SIZE='343087'
+ARCHIVE_BASE_CRIMSONCOURT_10_VERSION='26186c-gog83747'
+ARCHIVE_BASE_CRIMSONCOURT_10_URL='https://www.gog.com/game/darkest_dungeon_the_crimson_court'
+
+## This build is the one provided by GOG since 2025-05-29, but it is an old build from 2018.
 ARCHIVE_BASE_CRIMSONCOURT_9_NAME='darkest_dungeon_the_crimson_court_24788_82473.sh'
 ARCHIVE_BASE_CRIMSONCOURT_9_MD5='1d9d53d8100eb001402a48a7a37d50a9'
 ARCHIVE_BASE_CRIMSONCOURT_9_SIZE='342998'
 ARCHIVE_BASE_CRIMSONCOURT_9_VERSION='24788-gog82473'
-ARCHIVE_BASE_CRIMSONCOURT_9_URL='https://www.gog.com/game/darkest_dungeon_the_crimson_court'
 
 ## This build of the expansion is broken, many files are missing.
 ARCHIVE_BASE_CRIMSONCOURT_8_NAME='darkest_dungeon_the_crimson_court_26186_81633.sh'
@@ -131,13 +139,17 @@ ARCHIVE_BASE_CRIMSONCOURT_0_VERSION='20645-gog15279'
 
 ## The Shieldbreaker
 
-## This build is the one provided by GOG since 2025-05-29,
-## but it is an old build from 2018.
+ARCHIVE_BASE_SHIELDBREAKER_7_NAME='darkest_dungeon_the_shieldbreaker_26186c_83747.sh'
+ARCHIVE_BASE_SHIELDBREAKER_7_MD5='cc74051a999566bcdad375c9801129e2'
+ARCHIVE_BASE_SHIELDBREAKER_7_SIZE='40182'
+ARCHIVE_BASE_SHIELDBREAKER_7_VERSION='26186c-gog83747'
+ARCHIVE_BASE_SHIELDBREAKER_7_URL='https://www.gog.com/game/darkest_dungeon_the_shieldbreaker'
+
+## This build is the one provided by GOG since 2025-05-29, but it is an old build from 2018.
 ARCHIVE_BASE_SHIELDBREAKER_6_NAME='darkest_dungeon_the_shieldbreaker_24788_82473.sh'
 ARCHIVE_BASE_SHIELDBREAKER_6_MD5='ec9c10ddbd4833496cfdd26d37bfe485'
 ARCHIVE_BASE_SHIELDBREAKER_6_SIZE='40158'
 ARCHIVE_BASE_SHIELDBREAKER_6_VERSION='24788-gog82473'
-ARCHIVE_BASE_SHIELDBREAKER_6_URL='https://www.gog.com/game/darkest_dungeon_the_shieldbreaker'
 
 ARCHIVE_BASE_SHIELDBREAKER_5_NAME='darkest_dungeon_the_shieldbreaker_26186_81633.sh'
 ARCHIVE_BASE_SHIELDBREAKER_5_MD5='896d66ca296bc1b52988be55651d203a'
@@ -171,13 +183,17 @@ ARCHIVE_BASE_SHIELDBREAKER_0_VERSION='21142-gog16140'
 
 ## The Color of Madness
 
-## This build is the one provided by GOG since 2025-05-29,
-## but it is an old build from 2018.
+ARCHIVE_BASE_COLOROFMADNESS_7_NAME='darkest_dungeon_the_color_of_madness_26186c_83747.sh'
+ARCHIVE_BASE_COLOROFMADNESS_7_MD5='c9f3c570e143fd96c5d4b675ddd9cdd1'
+ARCHIVE_BASE_COLOROFMADNESS_7_SIZE='629799'
+ARCHIVE_BASE_COLOROFMADNESS_7_VERSION='26186c-gog83747'
+ARCHIVE_BASE_COLOROFMADNESS_7_URL='https://www.gog.com/game/darkest_dungeon_the_color_of_madness'
+
+## This build is the one provided by GOG since 2025-05-29, but it is an old build from 2018.
 ARCHIVE_BASE_COLOROFMADNESS_6_NAME='darkest_dungeon_the_color_of_madness_24788_82473.sh'
 ARCHIVE_BASE_COLOROFMADNESS_6_MD5='181fb603158b512b2b2c07730f9f9c0b'
 ARCHIVE_BASE_COLOROFMADNESS_6_SIZE='629673'
 ARCHIVE_BASE_COLOROFMADNESS_6_VERSION='24788-gog82473'
-ARCHIVE_BASE_COLOROFMADNESS_6_URL='https://www.gog.com/game/darkest_dungeon_the_color_of_madness'
 
 ARCHIVE_BASE_COLOROFMADNESS_5_NAME='darkest_dungeon_the_color_of_madness_26186_81633.sh'
 ARCHIVE_BASE_COLOROFMADNESS_5_MD5='a15a93c4a74c61b186210b97dcbc9383'
@@ -219,7 +235,7 @@ PKG_PARENT_ID="$GAME_ID"
 PKG_MAIN_DEPENDENCIES_SIBLINGS='
 PKG_PARENT'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -245,24 +261,24 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_default
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
