@@ -8,7 +8,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250722.2
+script_version=20250828.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -132,10 +132,11 @@ PKG_L10N_VOICES_FR_PROVIDES="$PKG_L10N_VOICES_PROVIDES"
 PKG_L10N_VOICES_EN_DESCRIPTION='English voices'
 PKG_L10N_VOICES_FR_DESCRIPTION='French voices'
 
-# unar is used to extract files from the disk image.
-
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-unar"
+## - unar is used to extract files from the disk image.
+## - convmv is used to convert file paths to lower case.
+REQUIREMENTS_LIST='
+unar
+convmv'
 
 # Load common functions.
 
