@@ -8,9 +8,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250606.1
+script_version=20251109.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='freelancer'
 GAME_NAME='Freelancer'
@@ -26,45 +26,79 @@ ARCHIVE_BASE_DEMO_EN_0_SIZE='450000'
 ARCHIVE_BASE_DEMO_EN_0_URL='https://archive.org/details/freelancer_demo'
 
 CONTENT_PATH_DEFAULT='.'
+## freelancer.exe requirements
+CONTENT_LIBS_BIN_PATH='cab1'
+CONTENT_LIBS_BIN_FILES='
+exe/Common.dll
+exe/DALib.dll
+exe/Movie.dll
+exe/DACOM.dll
+exe/ImeUI.dll'
+## DALib.dll requirements
+CONTENT_LIBS0_BIN_PATH='cab1'
+CONTENT_LIBS0_BIN_FILES='
+exe/zlib.dll'
+## A critical error is triggered on launch if the following library is missing.
+CONTENT_LIBS1_BIN_PATH='cab1'
+CONTENT_LIBS1_BIN_FILES='
+exe/ebueula.dll'
+## The game crashes on launch if any of the following libraries is missing.
+CONTENT_LIBS2_BIN_PATH='cab1'
+CONTENT_LIBS2_BIN_FILES='
+exe/engbase.dll
+exe/readfile.dll
+exe/rendcomp.dll
+exe/soundstreamer.dll
+exe/system.dll'
+## The game freezes before rendering the introduction videos if any of the following libraries is missing.
+CONTENT_LIBS3_BIN_PATH='cab1'
+CONTENT_LIBS3_BIN_FILES='
+exe/alchemy.dll
+exe/rp8.dll
+exe/shading.dll
+exe/x86math.dll'
+## The game crashes before reaching the menu if any of the following libraries is missing.
+CONTENT_LIBS4_BIN_PATH='cab1'
+CONTENT_LIBS4_BIN_FILES='
+exe/rpclocal.dll
+exe/server.dll'
+## The game freezes before reaching the menu if any of the following libraries is missing.
+CONTENT_LIBS5_BIN_PATH='cab1'
+CONTENT_LIBS5_BIN_FILES='
+dlls/bin/content.dll
+exe/thorn.dll'
+## The game freezes when trying to enter the options menu or quit the game if the following library is missing.
+CONTENT_LIBS6_BIN_PATH='cab1'
+CONTENT_LIBS6_BIN_FILES='
+exe/flmaterials.dll'
+## 2D pictures are not displayed if the following library is missing.
+CONTENT_LIBS7_BIN_PATH='cab1'
+CONTENT_LIBS7_BIN_FILES='
+exe/ximage.dll'
+## Sound effects (outside of music) do not play if the following library is missing.
+CONTENT_LIBS8_BIN_PATH='cab1'
+CONTENT_LIBS8_BIN_FILES='
+exe/soundmanager.dll'
+## The in-game introduction fails to play if the following library is missing.
+CONTENT_LIBS9_BIN_PATH='cab1'
+CONTENT_LIBS9_BIN_FILES='
+exe/deformable2.dll'
+## These libraries are required to display text strings in menus and in-game.
+CONTENT_LIBS_L10N_LIBS_PATH='cab1'
+CONTENT_LIBS_L10N_LIBS_FILES='
+exe/equipresources.dll
+exe/infocards.dll
+exe/misctext.dll
+exe/misctextinfo2.dll
+exe/nameresources.dll
+exe/offerbriberesources.dll
+exe/resources.dll
+exe/serverresources.dll'
 CONTENT_GAME_BIN_RELATIVE_PATH='game'
 CONTENT_GAME_BIN_FILES='
 exe/freelancer.exe'
 CONTENT_GAME0_BIN_PATH='cab1'
 CONTENT_GAME0_BIN_FILES='
-dlls
-exe/1033
-exe/alchemy.dll
-exe/common.dll
-exe/dacom.dll
-exe/dalib.dll
-exe/debuglib.dll
-exe/deformable2.dll
-exe/ebueula.dll
-exe/engbase.dll
-exe/flmaterials.dll
-exe/gundll.dll
-exe/imeui.dll
-exe/luaprofile.dll
-exe/movie.dll
-exe/msxml3a.dll
-exe/msxml3.dll
-exe/msxml3r.dll
-exe/readfile.dll
-exe/remoteclient.dll
-exe/remoteserver.dll
-exe/rendcomp.dll
-exe/rp8.dll
-exe/rpclocal.dll
-exe/server.dll
-exe/shading.dll
-exe/soundmanager.dll
-exe/soundstreamer.dll
-exe/system.dll
-exe/thorn.dll
-exe/unicows.dll
-exe/x86math.dll
-exe/ximage.dll
-exe/zlib.dll
 exe/*.bmp
 exe/*.exe
 exe/*.fl
@@ -77,15 +111,7 @@ data/audio/dialogue
 data/audio/mixes
 data/audio/sounds/ui/news_vendor_open.wav
 data/audio/*.ini
-data/audio/*.utf
-exe/equipresources.dll
-exe/infocards.dll
-exe/misctext.dll
-exe/misctextinfo2.dll
-exe/nameresources.dll
-exe/offerbriberesources.dll
-exe/resources.dll
-exe/serverresources.dll'
+data/audio/*.utf'
 CONTENT_GAME0_L10N_PATH='cab2'
 CONTENT_GAME0_L10N_FILES='
 data/audio/dialogue
@@ -124,6 +150,7 @@ APP_MAIN_ICON='fl.ico'
 PACKAGES_LIST='
 PKG_BIN
 PKG_L10N
+PKG_L10N_LIBS
 PKG_DATA'
 
 PKG_BIN_ARCH='32'
@@ -134,22 +161,27 @@ PKG_BIN_DEPENDENCIES_GSTREAMER_PLUGINS='
 deinterlace
 video/x-ms-asf'
 
+PKG_L10N_BASE_ID_DEMO="${GAME_ID_DEMO}-l10n"
+PKG_L10N_ID_DEMO_EN="${PKG_L10N_BASE_ID_DEMO}-en"
+PKG_L10N_PROVIDES_DEMO="
+$PKG_L10N_BASE_ID_DEMO"
+PKG_L10N_DESCRIPTION_DEMO_EN='English localisation'
+PKG_L10N_DEPENDENCIES_SIBLINGS='
+PKG_L10N_LIBS'
+
+PKG_L10N_LIBS_ID_DEMO_EN="${PKG_L10N_ID_DEMO_EN}-libs"
+PKG_L10N_LIBS_PROVIDES_DEMO="
+${PKG_L10N_BASE_ID_DEMO}-libs"
+PKG_L10N_LIBS_ARCH='32'
+PKG_L10N_LIBS_DESCRIPTION_DEMO_EN="$PKG_L10N_DESCRIPTION_DEMO_EN - libraries"
+## Prevent a fallback on PKG_L10N_DEPENDENCIES_SIBLINGS.
+PKG_L10N_LIBS_DEPENDENCIES_SIBLINGS=' '
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PKG_L10N_BASE_ID="${GAME_ID}-l10n"
-PKG_L10N_BASE_ID_DEMO="${GAME_ID_DEMO}-l10n"
-PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
-PKG_L10N_ID_DEMO_EN="${PKG_L10N_BASE_ID_DEMO}-en"
-PKG_L10N_PROVIDES="
-$PKG_L10N_BASE_ID"
-PKG_L10N_PROVIDES_DEMO="
-$PKG_L10N_BASE_ID_DEMO"
-PKG_L10N_DESCRIPTION_EN='English localization'
-PKG_L10N_DESCRIPTION_DEMO_EN='English localization'
-
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -175,41 +207,54 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 ARCHIVE_INNER1_PATH="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/cab1.cab"
 archive_extraction 'ARCHIVE_INNER1'
-rm "$(archive_path 'ARCHIVE_INNER1')"
+rm "$ARCHIVE_INNER1_PATH"
 ARCHIVE_INNER2_PATH="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/cab2.cab"
 archive_extraction 'ARCHIVE_INNER2'
-rm "$(archive_path 'ARCHIVE_INNER2')"
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME_BIN')"
+rm "$ARCHIVE_INNER2_PATH"
+## Rename a file with a truncated name.
+mv \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME_BIN')/exe/freela_1.exe" \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME_BIN')/exe/freelancer.exe"
 
-	## Rename files with truncated names.
-	mv 'exe/freela_1.exe' 'exe/freelancer.exe'
-)
-
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
