@@ -8,9 +8,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241227.1
+script_version=20251027.3
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='ghost-master'
 GAME_NAME='Ghost Master'
@@ -31,9 +31,6 @@ ARCHIVE_BASE_0_VERSION='1.1-gog2.0.0.3'
 CONTENT_PATH_DEFAULT='app/ghostdata'
 CONTENT_GAME_BIN_FILES='
 spdrv.cfg
-ogg.dll
-vorbis.dll
-vorbisfile.dll
 ghost.exe'
 CONTENT_GAME_DATA_FILES='
 characters
@@ -89,7 +86,7 @@ video/x-wmv, wmvversion=(int)1'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -115,29 +112,29 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+launchers_generation
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
