@@ -10,9 +10,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250606.1
+script_version=20251112.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID_ZEUS='zeus-master-of-olympus'
 GAME_NAME_ZEUS='Zeus: Master of Olympus'
@@ -20,10 +20,6 @@ GAME_NAME_ZEUS='Zeus: Master of Olympus'
 GAME_ID_EMPEROR='emperor-rise-of-the-middle-kingdom'
 GAME_NAME_EMPEROR='Emperor: Rise of the Middle Kingdom'
 
-# Game archives
-
-## Zeus
-
 ARCHIVE_BASE_ZEUS_0_NAME='setup_zeus_and_poseidon_2.1.0.10.exe'
 ARCHIVE_BASE_ZEUS_0_MD5='f26f9ed5ecaa4e58fca64acb88255107'
 ARCHIVE_BASE_ZEUS_0_TYPE='innosetup'
@@ -31,8 +27,6 @@ ARCHIVE_BASE_ZEUS_0_SIZE='800000'
 ARCHIVE_BASE_ZEUS_0_VERSION='2.1-gog2.1.0.10'
 ARCHIVE_BASE_ZEUS_0_URL='https://www.gog.com/game/zeus_poseidon'
 
-## Emperor
-
 ARCHIVE_BASE_EMPEROR_0_NAME='setup_emperor_rise_of_the_middle_kingdom_2.0.0.2.exe'
 ARCHIVE_BASE_EMPEROR_0_MD5='5e50e84c028a85eafe5dd5f2aa277fea'
 ARCHIVE_BASE_EMPEROR_0_TYPE='innosetup'
@@ -40,11 +34,14 @@ ARCHIVE_BASE_EMPEROR_0_SIZE='820000'
 ARCHIVE_BASE_EMPEROR_0_VERSION='1.0.1.0-gog2.0.0.2'
 ARCHIVE_BASE_EMPEROR_0_URL='https://www.gog.com/game/emperor_rise_of_the_middle_kingdom'
 
-
 CONTENT_PATH_DEFAULT='app'
+## zeus.exe / emperor.exe requirements
+CONTENT_LIBS_BIN_FILES='
+mss32.dll
+binkw32.dll
+ijl10.dll'
 CONTENT_GAME_BIN_FILES='
 *.asi
-*.dll
 *.exe
 *.ini
 *.m3d'
@@ -70,30 +67,25 @@ CONTENT_DOC_DATA_FILES='
 *editor*.txt
 *.pdf'
 
-# Applications
-
 USER_PERSISTENT_DIRECTORIES='
 save'
 USER_PERSISTENT_FILES='
 *.ini'
 
-## With the default OpenGL renderer, text boxes are not displayed (WINE 9.0).
+## With the default OpenGL renderer, text boxes are not displayed.
+## (WINE 9.0)
 WINE_DIRECT3D_RENDERER='wined3d/gdi'
-## The game window fails to render anything unless the game runs in a WINE virtual desktop (WINE 9.0).
-WINE_VIRTUAL_DESKTOP='auto'
+## The game window fails to render anything unless the game runs in a WINE virtual desktop.
+## (WINE 9.0)
+WINE_VIRTUAL_DESKTOP='1024x768'
 
-APPLICATIONS_LIST='APP_MAIN'
-
-## Zeus
+## TODO: Check if these explicit lists are required.
+APPLICATIONS_LIST_ZEUS='APP_MAIN'
+APPLICATIONS_LIST_EMPEROR='APP_MAIN APP_EDIT'
 
 APP_MAIN_EXE_ZEUS='zeus.exe'
-APP_MAIN_ICON_ZEUS='poseidon.ico'
-
-## Emperor
-
-APPLICATIONS_LIST_EMPEROR="$APPLICATIONS_LIST APP_EDIT"
-
 APP_MAIN_EXE_EMPEROR='emperor.exe'
+APP_MAIN_ICON_ZEUS='poseidon.ico'
 APP_MAIN_ICON_EMPEROR='dragon.ico'
 
 APP_EDIT_ID="${GAME_ID_EMPEROR}-editor"
@@ -101,7 +93,6 @@ APP_EDIT_NAME="$GAME_NAME_EMPEROR - Editor"
 APP_EDIT_EXE='emperoredit.exe'
 APP_EDIT_ICON="$APP_MAIN_ICON_EMPEROR"
 
-
 PACKAGES_LIST='
 PKG_BIN
 PKG_DATA'
@@ -114,7 +105,7 @@ PKG_DATA_ID_ZEUS="${GAME_ID_ZEUS}-data"
 PKG_DATA_ID_EMPEROR="${GAME_ID_EMPEROR}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -140,29 +131,37 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
