@@ -8,9 +8,10 @@ set -o errexit
 # Infinity Engine Enhanced Edition expansions:
 # - Baldur's Gate 1 Enhanced Edition - Siege of Dragonspear
 # - Baldur's Gate 1 Enhanced Edition - Faces of Good and Evil
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241226.1
+script_version=20250507.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -30,11 +31,16 @@ EXPANSION_NAME_FACES='Faces of Good and Evil'
 
 ## Baldur's Gate 1 Enhanced Edition - Siege of Dragonspear
 
+ARCHIVE_BASE_DRAGONSPEAR_2_NAME='baldur_s_gate_siege_of_dragonspear_2_6_6_0_p_81762.sh'
+ARCHIVE_BASE_DRAGONSPEAR_2_MD5='2bb1b6eaefb2744f9bbb32f82a30e60c'
+ARCHIVE_BASE_DRAGONSPEAR_2_SIZE='1887043'
+ARCHIVE_BASE_DRAGONSPEAR_2_VERSION='2.6.6.0-gog81762'
+ARCHIVE_BASE_DRAGONSPEAR_2_URL='https://www.gog.com/game/baldurs_gate_siege_of_dragonspear'
+
 ARCHIVE_BASE_DRAGONSPEAR_1_NAME='baldur_s_gate_siege_of_dragonspear_2_6_6_0_47291.sh'
 ARCHIVE_BASE_DRAGONSPEAR_1_MD5='36d275f6822b3cd2946ca606c0ebdb67'
 ARCHIVE_BASE_DRAGONSPEAR_1_SIZE='1900000'
 ARCHIVE_BASE_DRAGONSPEAR_1_VERSION='2.6.6.0-gog47291'
-ARCHIVE_BASE_DRAGONSPEAR_1_URL='https://www.gog.com/game/baldurs_gate_siege_of_dragonspear'
 
 ARCHIVE_BASE_DRAGONSPEAR_0_NAME='baldur_s_gate_siege_of_dragonspear_2_6_5_0_46477.sh'
 ARCHIVE_BASE_DRAGONSPEAR_0_MD5='27970876d9252fcb3174df8201db3ca3'
@@ -43,11 +49,16 @@ ARCHIVE_BASE_DRAGONSPEAR_0_VERSION='2.6.5.0-gog46477'
 
 ## Baldur's Gate 1 Enhanced Edition - Faces of Good and Evil
 
+ARCHIVE_BASE_FACES_2_NAME='baldur_s_gate_faces_of_good_and_evil_2_6_6_0_p_81762.sh'
+ARCHIVE_BASE_FACES_2_MD5='6289884d62f5b9726c52050787be8099'
+ARCHIVE_BASE_FACES_2_SIZE='2119'
+ARCHIVE_BASE_FACES_2_VERSION='2.6.6.0-gog81762'
+ARCHIVE_BASE_FACES_2_URL='https://www.gog.com/game/baldurs_gate_faces_of_good_and_evil'
+
 ARCHIVE_BASE_FACES_1_NAME='baldur_s_gate_faces_of_good_and_evil_2_6_6_0_47291.sh'
 ARCHIVE_BASE_FACES_1_MD5='5bcc622e44bdf9b03af64f5fe0a83d38'
 ARCHIVE_BASE_FACES_1_SIZE='2500'
 ARCHIVE_BASE_FACES_1_VERSION='2.6.6.0-gog47291'
-ARCHIVE_BASE_FACES_1_URL='https://www.gog.com/game/baldurs_gate_faces_of_good_and_evil'
 
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
