@@ -13,7 +13,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250908.5
+script_version=20251112.5
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -21,19 +21,17 @@ GAME_ID_BG1='baldurs-gate-1'
 GAME_NAME_BG1='Baldurʼs Gate'
 
 GAME_ID_BG2='baldurs-gate-2'
-GAME_NAME_BG2='Baldurʼs Gate Ⅱ'
+GAME_NAME_BG2='Baldurʼs Gate II'
 
 GAME_ID_IWD1='icewind-dale-1'
 GAME_NAME_IWD1='Icewind Dale'
 
 GAME_ID_IWD2='icewind-dale-2'
-GAME_NAME_IWD2='Icewind Dale Ⅱ'
+GAME_NAME_IWD2='Icewind Dale II'
 
 GAME_ID_PST='planescape-torment'
 GAME_NAME_PST='Planescape: Torment'
 
-# Game archives
-
 ## Baldur's Gate
 
 ARCHIVE_BASE_BG1_DE_1_NAME='baldur_s_gate_the_original_saga_german_gog_3_23532.sh'
@@ -198,8 +196,6 @@ ARCHIVE_BASE_PST_EN_0_MD5='a48bb772f60da3b5b2cac804b6e92670'
 ARCHIVE_BASE_PST_EN_0_SIZE='2400000'
 ARCHIVE_BASE_PST_EN_0_VERSION='1.1-gog2.1.0.9'
 
-# Archives content
-
 ## Baldur's Gate
 
 CONTENT_PATH_DEFAULT_BG1_DE="data/noarch/prefix/drive_c/GOG Games/Baldur's Gate (German)"
@@ -300,7 +296,6 @@ CONTENT_DOC_L10N_FILES_BG2='
 
 CONTENT_PATH_DEFAULT_IWD1='app'
 CONTENT_GAME_BIN_FILES_IWD1='
-3dfx.dll
 config.exe
 glsetup.exe
 idmain.exe
@@ -344,8 +339,10 @@ readme_eng.txt'
 CONTENT_PATH_DEFAULT_IWD2='.'
 CONTENT_PATH_DEFAULT_IWD2_FR_0='app'
 CONTENT_PATH_DEFAULT_IWD2_EN_0='app'
+## The following library is required to play videos.
+CONTENT_LIBS_BIN_FILES_IWD2='
+binkw32.dll'
 CONTENT_GAME_BIN_FILES_IWD2='
-binkw32.dll
 config.exe
 iwd2.exe
 keymap.ini'
@@ -427,8 +424,6 @@ CONTENT_DOC_L10N_FILES_PST='
 *.pdf
 *.txt'
 
-# Applications
-
 USER_PERSISTENT_FILES='
 *.ini'
 USER_PERSISTENT_DIRECTORIES='
@@ -436,58 +431,33 @@ characters
 mpsave
 save'
 
-## Disable the multi-threaded command stream feature, as it has a very severe impact on performances.
-WINE_WINETRICKS_VERBS='csmt=off'
-
 APPLICATIONS_LIST='APP_MAIN APP_CONFIG'
 APPLICATIONS_LIST_PST='APP_MAIN'
 
-APP_CONFIG_CAT='Settings'
-
-## Baldur's Gate
-
 APP_MAIN_EXE_BG1='bgmain2.exe'
-APP_MAIN_ICON_BG1='baldur.exe'
-
-APP_CONFIG_ID_BG1="${GAME_ID_BG1}-config"
-APP_CONFIG_NAME_BG1="$GAME_NAME_BG1 - configuration"
-APP_CONFIG_EXE_BG1='config.exe'
-
-## Baldur's Gate 2
-
 APP_MAIN_EXE_BG2='bgmain.exe'
-APP_MAIN_ICON_BG2='baldur.exe'
-
-APP_CONFIG_ID_BG2="${GAME_ID_BG2}-config"
-APP_CONFIG_NAME_BG2="$GAME_NAME_BG2 - configuration"
-APP_CONFIG_EXE_BG2='bgconfig.exe'
-
-## Icewind Dale
-
 APP_MAIN_EXE_IWD1='idmain.exe'
-
-APP_CONFIG_ID_IWD1="${GAME_ID_IWD1}-config"
-APP_CONFIG_NAME_IWD1="$GAME_NAME_IWD1 - configuration"
-APP_CONFIG_EXE_IWD1='config.exe'
-
-## Icewind Dale 2
-
 APP_MAIN_EXE_IWD2='iwd2.exe'
+APP_MAIN_EXE_PST='torment.exe'
+APP_MAIN_ICON_BG1='baldur.exe'
+APP_MAIN_ICON_BG2='baldur.exe'
 APP_MAIN_ICON_IWD2='__support/app/iwd2.exe'
 APP_MAIN_ICON_IWD2_FR_0='iwd2.exe'
 APP_MAIN_ICON_IWD2_EN_0='iwd2.exe'
 
+APP_CONFIG_ID_BG1="${GAME_ID_BG1}-config"
+APP_CONFIG_ID_BG2="${GAME_ID_BG2}-config"
+APP_CONFIG_ID_IWD1="${GAME_ID_IWD1}-config"
 APP_CONFIG_ID_IWD2="${GAME_ID_IWD2}-config"
+APP_CONFIG_NAME_BG1="$GAME_NAME_BG1 - configuration"
+APP_CONFIG_NAME_BG2="$GAME_NAME_BG2 - configuration"
+APP_CONFIG_NAME_IWD1="$GAME_NAME_IWD1 - configuration"
 APP_CONFIG_NAME_IWD2="$GAME_NAME_IWD2 - configuration"
+APP_CONFIG_EXE_BG1='config.exe'
+APP_CONFIG_EXE_BG2='bgconfig.exe'
+APP_CONFIG_EXE_IWD1='config.exe'
 APP_CONFIG_EXE_IWD2='config.exe'
-
-## Planescape: Torment
-
-APP_MAIN_EXE_PST='torment.exe'
-
-# Packages
-
-## Common
+APP_CONFIG_CAT='Settings'
 
 PACKAGES_LIST='
 PKG_BIN
@@ -499,87 +469,63 @@ PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_L10N_BASE
 PKG_DATA'
 
-PKG_L10N_DESCRIPTION_DE='German localisation'
-PKG_L10N_DESCRIPTION_FR='French localisation'
-PKG_L10N_DESCRIPTION_PL='Polish localisation'
-PKG_L10N_DESCRIPTION_RU='Russian localisation'
-PKG_L10N_DESCRIPTION_EN='English localisation'
-
-PKG_DATA_DESCRIPTION='data'
-
-## Baldur's Gate
-
 PKG_L10N_BASE_ID_BG1="${GAME_ID_BG1}-l10n"
+PKG_L10N_BASE_ID_BG2="${GAME_ID_BG2}-l10n"
+PKG_L10N_BASE_ID_IWD1="${GAME_ID_IWD1}-l10n"
+PKG_L10N_BASE_ID_IWD2="${GAME_ID_IWD2}-l10n"
+PKG_L10N_BASE_ID_PST="${GAME_ID_PST}-l10n"
 PKG_L10N_ID_BG1_DE="${PKG_L10N_BASE_ID_BG1}-de"
 PKG_L10N_ID_BG1_FR="${PKG_L10N_BASE_ID_BG1}-fr"
 PKG_L10N_ID_BG1_PL="${PKG_L10N_BASE_ID_BG1}-pl"
 PKG_L10N_ID_BG1_EN="${PKG_L10N_BASE_ID_BG1}-en"
-PKG_L10N_PROVIDES_BG1="
-$PKG_L10N_BASE_ID_BG1"
-PKG_L10N_DESCRIPTION_BG1_DE="$PKG_L10N_DESCRIPTION_DE"
-PKG_L10N_DESCRIPTION_BG1_FR="$PKG_L10N_DESCRIPTION_FR"
-PKG_L10N_DESCRIPTION_BG1_PL="$PKG_L10N_DESCRIPTION_PL"
-PKG_L10N_DESCRIPTION_BG1_EN="$PKG_L10N_DESCRIPTION_EN"
-
-PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
-
-## Baldur's Gate 2
-
-PKG_L10N_BASE_ID_BG2="${GAME_ID_BG2}-l10n"
 PKG_L10N_ID_BG2_DE="${PKG_L10N_BASE_ID_BG2}-de"
 PKG_L10N_ID_BG2_FR="${PKG_L10N_BASE_ID_BG2}-fr"
 PKG_L10N_ID_BG2_EN="${PKG_L10N_BASE_ID_BG2}-en"
-PKG_L10N_PROVIDES_BG2="
-$PKG_L10N_BASE_ID_BG2"
-PKG_L10N_DESCRIPTION_BG2_DE="$PKG_L10N_DESCRIPTION_DE"
-PKG_L10N_DESCRIPTION_BG2_FR="$PKG_L10N_DESCRIPTION_FR"
-PKG_L10N_DESCRIPTION_BG2_EN="$PKG_L10N_DESCRIPTION_EN"
-
-PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
-
-## Icewind Dale
-
-PKG_L10N_BASE_ID_IWD1="${GAME_ID_IWD1}-l10n"
 PKG_L10N_ID_IWD1_DE="${PKG_L10N_BASE_ID_IWD1}-de"
 PKG_L10N_ID_IWD1_EN="${PKG_L10N_BASE_ID_IWD1}-en"
-PKG_L10N_PROVIDES_IWD1="
-$PKG_L10N_BASE_ID_IWD1"
-PKG_L10N_DESCRIPTION_IWD1_DE="$PKG_L10N_DESCRIPTION_DE"
-PKG_L10N_DESCRIPTION_IWD1_EN="$PKG_L10N_DESCRIPTION_EN"
-
-PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
-
-## Icewind Dale 2
-
-PKG_L10N_BASE_ID_IWD2="${GAME_ID_IWD2}-l10n"
 PKG_L10N_ID_IWD2_DE="${PKG_L10N_BASE_ID_IWD2}-de"
 PKG_L10N_ID_IWD2_EN="${PKG_L10N_BASE_ID_IWD2}-en"
 PKG_L10N_ID_IWD2_FR="${PKG_L10N_BASE_ID_IWD2}-fr"
-PKG_L10N_PROVIDES_IWD2="
-$PKG_L10N_BASE_ID_IWD2"
-PKG_L10N_DESCRIPTION_IWD2_DE="$PKG_L10N_DESCRIPTION_DE"
-PKG_L10N_DESCRIPTION_IWD2_FR="$PKG_L10N_DESCRIPTION_FR"
-PKG_L10N_DESCRIPTION_IWD2_EN="$PKG_L10N_DESCRIPTION_EN"
-
-PKG_DATA_ID_IWD2="${GAME_ID_IWD2}-data"
-
-## Planescape: Torment
-
-PKG_L10N_BASE_ID_PST="${GAME_ID_PST}-l10n"
 PKG_L10N_ID_PST_DE="${PKG_L10N_BASE_ID_PST}-de"
 PKG_L10N_ID_PST_FR="${PKG_L10N_BASE_ID_PST}-fr"
 PKG_L10N_ID_PST_RU="${PKG_L10N_BASE_ID_PST}-ru"
 PKG_L10N_ID_PST_EN="${PKG_L10N_BASE_ID_PST}-en"
+PKG_L10N_PROVIDES_BG1="
+$PKG_L10N_BASE_ID_BG1"
+PKG_L10N_PROVIDES_BG2="
+$PKG_L10N_BASE_ID_BG2"
+PKG_L10N_PROVIDES_IWD1="
+$PKG_L10N_BASE_ID_IWD1"
+PKG_L10N_PROVIDES_IWD2="
+$PKG_L10N_BASE_ID_IWD2"
 PKG_L10N_PROVIDES_PST="
 $PKG_L10N_BASE_ID_PST"
-PKG_L10N_DESCRIPTION_PST_DE="$PKG_L10N_DESCRIPTION_DE"
-PKG_L10N_DESCRIPTION_PST_FR="$PKG_L10N_DESCRIPTION_FR"
-PKG_L10N_DESCRIPTION_PST_RU="$PKG_L10N_DESCRIPTION_RU"
-PKG_L10N_DESCRIPTION_PST_EN="$PKG_L10N_DESCRIPTION_EN"
+PKG_L10N_DESCRIPTION_BG1_DE='German localisation'
+PKG_L10N_DESCRIPTION_BG1_FR='French localisation'
+PKG_L10N_DESCRIPTION_BG1_PL='Polish localisation'
+PKG_L10N_DESCRIPTION_BG1_EN='English localisation'
+PKG_L10N_DESCRIPTION_BG2_DE='German localisation'
+PKG_L10N_DESCRIPTION_BG2_FR='French localisation'
+PKG_L10N_DESCRIPTION_BG2_EN='English localisation'
+PKG_L10N_DESCRIPTION_IWD1_DE='German localisation'
+PKG_L10N_DESCRIPTION_IWD1_EN='English localisation'
+PKG_L10N_DESCRIPTION_IWD2_DE='German localisation'
+PKG_L10N_DESCRIPTION_IWD2_FR='French localisation'
+PKG_L10N_DESCRIPTION_IWD2_EN='English localisation'
+PKG_L10N_DESCRIPTION_PST_DE='German localisation'
+PKG_L10N_DESCRIPTION_PST_FR='French localisation'
+PKG_L10N_DESCRIPTION_PST_RU='Russian localisation'
+PKG_L10N_DESCRIPTION_PST_EN='English localisation'
 
+PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
+PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
+PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
+PKG_DATA_ID_IWD2="${GAME_ID_IWD2}-data"
 PKG_DATA_ID_PST="${GAME_ID_PST}-data"
+PKG_DATA_DESCRIPTION='data'
+
+# convmv is used to convert file paths to lower case.
 
-## convmv is used to convert file paths to lower case.
 REQUIREMENTS_LIST_BG1='
 convmv'
 REQUIREMENTS_LIST_BG2='
@@ -587,7 +533,7 @@ convmv'
 REQUIREMENTS_LIST_PST='
 convmv'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -613,142 +559,158 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+## Mojosetup installers - Convert all file names to lowercase
+if [ "$(archive_type "$(current_archive)")" = 'mojosetup' ]; then
+	tolower "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+fi
+## Baldur's Gate 2
+case "$(current_archive)" in
+	('ARCHIVE_BASE_BG2_'*)
+		# Delete broken symbolic links.
+		## TODO: Check if this is still required.
+		rm --force --recursive \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/mpsave" \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/temp"
+		# Drop duplicated files.
+		rm \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/data/data/cd3crean.bif" \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/data/data/cd4crea3.bif"
+		if [ -e "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/data/data/cdcreani.bif" ]; then
+			mv \
+				"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/data/data/cdcreani.bif" \
+				"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/data/cdcreani.bif"
+		fi
+	;;
+esac
 
-	## Mojosetup installers
-	## - Convert all file names to lowercase
-	if [ "$(archive_type "$(current_archive)")" = 'mojosetup' ]; then
-		tolower .
-	fi
+# Generate a minimal configuration file.
 
-	# Baldur's Gate 2 - Delete broken symbolic links.
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_BG2_'*)
-			rm --force --recursive \
-				'mpsave' \
-				'temp'
-		;;
-	esac
+case "$(current_archive)" in
+	('ARCHIVE_BASE_BG1_'*)
+		config_name='baldur.ini'
+	;;
+	('ARCHIVE_BASE_BG2_'*)
+		config_name='baldur.ini'
+	;;
+	('ARCHIVE_BASE_IWD1_'*)
+		config_name='icewind.ini'
+	;;
+	('ARCHIVE_BASE_IWD2_'*)
+		config_name='icewind2.ini'
+	;;
+	('ARCHIVE_BASE_PST_'*)
+		config_name='torment.ini'
+	;;
+esac
+config_file="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${config_name}"
+game_path="C:\\$(game_id)"
+case "$(current_archive)" in
+	('ARCHIVE_BASE_BG1_'*)
+		cat > "$config_file" <<- EOF
+		[Alias]
+		HD0:=${game_path}\\
+		CD1:=${game_path}\\data\\
+		CD2:=${game_path}\\data\\
+		CD3:=${game_path}\\data\\
+		CD4:=${game_path}\\data\\
+		CD5:=${game_path}\\data\\
+		CD6:=${game_path}\\data\\
+		EOF
+	;;
+	('ARCHIVE_BASE_BG2_'*)
+		cat > "$config_file" <<- EOF
+		[Alias]
+		HD0:=${game_path}\\
+		CD1:=${game_path}\\data\\
+		CD2:=${game_path}\\data\\
+		CD3:=${game_path}\\data\\
+		CD4:=${game_path}\\data\\
+		CD5:=${game_path}\\data\\
+		CD6:=${game_path}\\data\\
+		EOF
+	;;
+	('ARCHIVE_BASE_IWD1_'*)
+		cat > "$config_file" <<- EOF
+		[Alias]
+		HD0:=${game_path}\\
+		CD1:=${game_path}\\
+		CD2:=${game_path}\\cd2\\
+		CD3:=${game_path}\\cd3\\
+		EOF
+	;;
+	('ARCHIVE_BASE_IWD2_'*)
+		cat > "$config_file" <<- EOF
+		[Alias]
+		HD0:=${game_path}\\
+		CD1:=${game_path}\\data\\
+		CD2:=${game_path}\\cd2\\
+		[Movies]
+		INTRO=1
+		EOF
+	;;
+	('ARCHIVE_BASE_PST_'*)
+		cat > "$config_file" <<- EOF
+		[Alias]
+		HD0:=${game_path}\\
+		CD1:=${game_path}\\data\\
+		CD2:=${game_path}\\data\\
+		CD3:=${game_path}\\data\\
+		CD4:=${game_path}\\data\\
+		CD5:=${game_path}\\data\\
+		EOF
+	;;
+esac
+## The native windowed mode is used instead of a WINE virtual desktop, as using a WINE virtual desktop would cause cursor flickering.
+## cf. https://bugs.winehq.org/show_bug.cgi?id=56986
+## At least with Baldur's Gate 2, the cursor flickering can be avoided by enabling 3D acceleration.
+## The lack of a WINE virtual desktop can cause loss of display and input on loss of focus, but only when the game is running in fullscreen.
+## (WINE 9.13).
+cat >> "$config_file" <<- EOF
+[Program Options]
+Full Screen=0
+EOF
 
-	# Baldur's Gate 2 - Drop duplicated files.
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_BG2_'*)
-			rm \
-				'data/data/cd3crean.bif' \
-				'data/data/cd4crea3.bif'
-			if [ -e 'data/data/cdcreani.bif' ]; then
-				mv 'data/data/cdcreani.bif' 'data/cdcreani.bif'
-			fi
-		;;
-	esac
-
-	## Generate a minimal configuration file
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_BG1_'*)
-			config_file='baldur.ini'
-		;;
-		('ARCHIVE_BASE_BG2_'*)
-			config_file='baldur.ini'
-		;;
-		('ARCHIVE_BASE_IWD1_'*)
-			config_file='icewind.ini'
-		;;
-		('ARCHIVE_BASE_IWD2_'*)
-			config_file='icewind2.ini'
-		;;
-		('ARCHIVE_BASE_PST_'*)
-			config_file='torment.ini'
-		;;
-	esac
-	game_path="C:\\$(game_id)"
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_BG1_'*)
-			cat > "$config_file" <<- EOF
-			[Alias]
-			HD0:=${game_path}\\
-			CD1:=${game_path}\\data\\
-			CD2:=${game_path}\\data\\
-			CD3:=${game_path}\\data\\
-			CD4:=${game_path}\\data\\
-			CD5:=${game_path}\\data\\
-			CD6:=${game_path}\\data\\
-			EOF
-		;;
-		('ARCHIVE_BASE_BG2_'*)
-			cat > "$config_file" <<- EOF
-			[Alias]
-			HD0:=${game_path}\\
-			CD1:=${game_path}\\data\\
-			CD2:=${game_path}\\data\\
-			CD3:=${game_path}\\data\\
-			CD4:=${game_path}\\data\\
-			CD5:=${game_path}\\data\\
-			CD6:=${game_path}\\data\\
-			EOF
-		;;
-		('ARCHIVE_BASE_IWD1_'*)
-			cat > "$config_file" <<- EOF
-			[Alias]
-			HD0:=${game_path}\\
-			CD1:=${game_path}\\
-			CD2:=${game_path}\\cd2\\
-			CD3:=${game_path}\\cd3\\
-			EOF
-		;;
-		('ARCHIVE_BASE_IWD2_'*)
-			cat > "$config_file" <<- EOF
-			[Alias]
-			HD0:=${game_path}\\
-			CD1:=${game_path}\\data\\
-			CD2:=${game_path}\\cd2\\
-			[Movies]
-			INTRO=1
-			EOF
-		;;
-		('ARCHIVE_BASE_PST_'*)
-			cat > "$config_file" <<- EOF
-			[Alias]
-			HD0:=${game_path}\\
-			CD1:=${game_path}\\data\\
-			CD2:=${game_path}\\data\\
-			CD3:=${game_path}\\data\\
-			CD4:=${game_path}\\data\\
-			CD5:=${game_path}\\data\\
-			EOF
-		;;
-	esac
-	## The native windowed mode is used instead of a WINE virtual desktop,
-	## as using a WINE virtual desktop would cause cursor flickering (WINE 9.0).
-	## cf. https://bugs.winehq.org/show_bug.cgi?id=56986
-	cat >> "$config_file" <<- EOF
-	[Program Options]
-	Full Screen=0
-	EOF
-)
-
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
+
+## Icewind Dale 2 - Install shipped libraries.
+case "$(current_archive)" in
+	('ARCHIVE_BASE_IWD2_'*)
+		wineprefix_init_custom() {
+			cat <<- EOF
+			# Install shipped libraries.
+			PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+			EOF
+			cat <<- 'EOF'
+			find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+				dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+			    mkdir --parents "$(dirname "$dll_destination")"
+			    ln --symbolic "$dll_source" "$dll_destination"
+			done
+			EOF
+		}
+	;;
+esac
 
 launchers_generation
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
