@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Jazz Jackrabbit 2
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241123.3
+script_version=20250725.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='jazz-jackrabbit-2'
 GAME_NAME='Jazz Jackrabbit 2'
@@ -75,21 +76,26 @@ ARCHIVE_BASE_CHRISTMAS_0_VERSION='1.2x-gog16742'
 
 ## Jazz² Resurrection (native engine)
 
+ARCHIVE_JAZZ2NATIVE_4_NAME='Jazz2_3.3.0_Linux.zip'
+ARCHIVE_JAZZ2NATIVE_4_MD5='09b746e3bb4248eefcf3695931e99986'
+ARCHIVE_JAZZ2NATIVE_4_SIZE='42311'
+ARCHIVE_JAZZ2NATIVE_4_VERSION='3.3.0-1'
+ARCHIVE_JAZZ2NATIVE_4_URL='http://deat.tk/jazz2/'
+
 ARCHIVE_JAZZ2NATIVE_3_NAME='Jazz2_2.9.1_Linux.zip'
 ARCHIVE_JAZZ2NATIVE_3_MD5='7a0b286248e54ab652f4f0e437912961'
 ARCHIVE_JAZZ2NATIVE_3_SIZE='30115'
-ARCHIVE_JAZZ2NATIVE_3_VERSION='2.9.1'
-ARCHIVE_JAZZ2NATIVE_3_URL='http://deat.tk/jazz2/'
+ARCHIVE_JAZZ2NATIVE_3_VERSION='2.9.1-1'
 
 ARCHIVE_JAZZ2NATIVE_2_NAME='Jazz2_2.7.0_Linux.zip'
 ARCHIVE_JAZZ2NATIVE_2_MD5='50fd07614c030c2e86498894f67cf203'
 ARCHIVE_JAZZ2NATIVE_2_SIZE='29747'
-ARCHIVE_JAZZ2NATIVE_2_VERSION='2.7.0'
+ARCHIVE_JAZZ2NATIVE_2_VERSION='2.7.0-1'
 
 ARCHIVE_JAZZ2NATIVE_1_NAME='Jazz2_2.6.0_Linux.zip'
 ARCHIVE_JAZZ2NATIVE_1_MD5='ff2ff3acc2213f4133ca8138603feb67'
 ARCHIVE_JAZZ2NATIVE_1_SIZE='29553'
-ARCHIVE_JAZZ2NATIVE_1_VERSION='2.6.0'
+ARCHIVE_JAZZ2NATIVE_1_VERSION='2.6.0-1'
 
 # Archives content
 
@@ -124,77 +130,22 @@ CONTENT_DOC_DATA_FILES='
 CONTENT_GAME0_DATA_PATH='x64'
 CONTENT_GAME0_DATA_FILES='
 Content'
-
-CONTENT_GAME_BIN_DEFAULT_PATH='x64'
-CONTENT_GAME_BIN_DEFAULT_FILES='
-jazz2'
-
-CONTENT_GAME_BIN_SDL_PATH='x64'
-CONTENT_GAME_BIN_SDL_FILES='
+CONTENT_GAME_BIN_PATH='x64'
+CONTENT_GAME_BIN_FILES='
 jazz2_sdl2'
 
 
-APP_MAIN_EXE_BIN_DEFAULT='jazz2'
-APP_MAIN_EXE_BIN_SDL='jazz2_sdl2'
+APP_MAIN_EXE_BIN='jazz2_sdl2'
 APP_MAIN_ICON='jazz2.exe'
 
 PACKAGES_LIST='
-PKG_BIN_DEFAULT
-PKG_BIN_SDL
+PKG_BIN
 PKG_DATA'
 
-PKG_BIN_ID="${GAME_ID}-bin"
-PKG_BIN_ID_JJ2PLUS="${GAME_ID_JJ2PLUS}-bin"
-PKG_BIN_ID_CHRISTMAS="${GAME_ID_CHRISTMAS}-bin"
-PKG_BIN_PROVIDES="
-$PKG_BIN_ID"
-PKG_BIN_PROVIDES_JJ2PLUS="
-$PKG_BIN_ID_JJ2PLUS"
-PKG_BIN_PROVIDES_CHRISTMAS="
-$PKG_BIN_ID_CHRISTMAS"
-
-PKG_BIN_DEFAULT_ID="${PKG_BIN_ID}-default"
-PKG_BIN_DEFAULT_ID_JJ2PLUS="${PKG_BIN_ID_JJ2PLUS}-default"
-PKG_BIN_DEFAULT_ID_CHRISTMAS="${PKG_BIN_ID_CHRISTMAS}-default"
-PKG_BIN_DEFAULT_PROVIDES="$PKG_BIN_PROVIDES"
-PKG_BIN_DEFAULT_PROVIDES_JJ2PLUS="$PKG_BIN_PROVIDES_JJ2PLUS"
-PKG_BIN_DEFAULT_PROVIDES_CHRISTMAS="$PKG_BIN_PROVIDES_CHRISTMAS"
-PKG_BIN_DEFAULT_ARCH='64'
-PKG_BIN_DEFAULT_DEPENDENCIES_SIBLINGS='
+PKG_BIN_ARCH='64'
+PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN_DEFAULT_DEPENDENCIES_LIBRARIES='
-libc.so.6
-libgcc_s.so.1
-libglfw.so.3
-libm.so.6
-libopenal.so.1
-libOpenGL.so.0
-libopenmpt.so.0
-libstdc++.so.6
-libvorbisfile.so.3
-libz.so.1'
-## Ensure smooth upgrades from packages generated with pre-20241123.3 game scripts
-PKG_BIN_DEFAULT_PROVIDES="${PKG_BIN_DEFAULT_PROVIDES:-}
-jazz-jackrabbit-2
-jazz-jackrabbit-2-bin"
-PKG_BIN_DEFAULT_PROVIDES_CHRISTMAS="${PKG_BIN_DEFAULT_PROVIDES_CHRISTMAS:-}
-jazz-jackrabbit-2-the-christmas-chronicles
-jazz-jackrabbit-2-the-christmas-chronicles-bin"
-### This one is not actually required, but prevents the JJ2+ package from conflicting with the regular one.
-PKG_BIN_DEFAULT_PROVIDES_JJ2PLUS="${PKG_BIN_DEFAULT_PROVIDES_JJ2PLUS:-}
-jazz-jackrabbit-2-jj2plus
-jazz-jackrabbit-2-jj2plus-bin"
-
-PKG_BIN_SDL_ID="${PKG_BIN_ID}-sdl"
-PKG_BIN_SDL_ID_JJ2PLUS="${PKG_BIN_ID_JJ2PLUS}-sdl"
-PKG_BIN_SDL_ID_CHRISTMAS="${PKG_BIN_ID_CHRISTMAS}-sdl"
-PKG_BIN_SDL_PROVIDES="$PKG_BIN_PROVIDES"
-PKG_BIN_SDL_PROVIDES_JJ2PLUS="$PKG_BIN_PROVIDES_JJ2PLUS"
-PKG_BIN_SDL_PROVIDES_CHRISTMAS="$PKG_BIN_PROVIDES_CHRISTMAS"
-PKG_BIN_SDL_ARCH='64'
-PKG_BIN_SDL_DEPENDENCIES_SIBLINGS='
-PKG_DATA'
-PKG_BIN_SDL_DEPENDENCIES_LIBRARIES='
+PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libgcc_s.so.1
 libm.so.6
@@ -205,16 +156,12 @@ libSDL2-2.0.so.0
 libstdc++.so.6
 libvorbisfile.so.3
 libz.so.1'
-## Ensure smooth upgrades from packages generated with pre-20241123.3 game scripts
-PKG_BIN_SDL_PROVIDES="${PKG_BIN_SDL_PROVIDES:-}
-jazz-jackrabbit-2
+## Easier upgrades from pre-20250605.2 packages
+PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
 jazz-jackrabbit-2-bin"
-PKG_BIN_SDL_PROVIDES_CHRISTMAS="${PKG_BIN_SDL_PROVIDES_CHRISTMAS:-}
-jazz-jackrabbit-2-the-christmas-chronicles
+PKG_BIN_PROVIDES_CHRISTMAS="${PKG_BIN_PROVIDES_CHRISTMAS:-}
 jazz-jackrabbit-2-the-christmas-chronicles-bin"
-### This one is not actually required, but prevents the JJ2+ package from conflicting with the regular one.
-PKG_BIN_SDL_PROVIDES_JJ2PLUS="${PKG_BIN_SDL_PROVIDES_JJ2PLUS:-}
-jazz-jackrabbit-2-jj2plus
+PKG_BIN_PROVIDES_JJ2PLUS="${PKG_BIN_PROVIDES_JJ2PLUS:-}
 jazz-jackrabbit-2-jj2plus-bin"
 
 PKG_DATA_ID="${GAME_ID}-data"
@@ -252,27 +199,17 @@ fi
 
 initialization_default "$@"
 
-# Check for the presence of required extra archives
+# Check for the presence of the game engine archive.
 
 archive_initialize_required \
 	'ARCHIVE_JAZZ2NATIVE' \
+	'ARCHIVE_JAZZ2NATIVE_4' \
 	'ARCHIVE_JAZZ2NATIVE_3' \
 	'ARCHIVE_JAZZ2NATIVE_2' \
 	'ARCHIVE_JAZZ2NATIVE_1'
-installer_release=$(package_version | cut --delimiter='-' --fields=2)
-## TODO: The following test could be avoided if the library did set ARCHIVE_xxx_VERSION through archive_initialize_required
-##       cf. https://forge.dotslashplay.it/play.it/play.it/-/issues/550
-case "$(archive_name 'ARCHIVE_JAZZ2NATIVE')" in
-	("$(archive_name 'ARCHIVE_JAZZ2NATIVE_3')")
-		export "$(current_archive)_VERSION=${ARCHIVE_JAZZ2NATIVE_3_VERSION}-${installer_release}"
-	;;
-	("$(archive_name 'ARCHIVE_JAZZ2NATIVE_2')")
-		export "$(current_archive)_VERSION=${ARCHIVE_JAZZ2NATIVE_2_VERSION}-${installer_release}"
-	;;
-	("$(archive_name 'ARCHIVE_JAZZ2NATIVE_1')")
-		export "$(current_archive)_VERSION=${ARCHIVE_JAZZ2NATIVE_1_VERSION}-${installer_release}"
-	;;
-esac
+archive_version=$(archive_version 'ARCHIVE_JAZZ2NATIVE' | cut --delimiter='-' --fields=1)
+archive_release=$(archive_version "$(current_archive)" | cut --delimiter='-' --fields=2)
+export "$(current_archive)_VERSION=${archive_version}-${archive_release}"
 
 # Extract game data
 
@@ -287,17 +224,12 @@ content_inclusion_default
 
 # Write launchers
 
-launchers_generation 'PKG_BIN_DEFAULT'
-launchers_generation 'PKG_BIN_SDL'
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-printf '\n'
-printf 'Default binaries:'
-print_instructions 'PKG_BIN_DEFAULT' 'PKG_DATA'
-printf 'SDL build:'
-print_instructions 'PKG_BIN_SDL' 'PKG_DATA'
+print_instructions
 
 # Clean up
 
