@@ -9,15 +9,13 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250722.1
+script_version=20251103.3
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='monkey-island-4'
 GAME_NAME='Monkey Island 4: Escape from Monkey Island'
 
-# Archives
-
 ## Monkey Island 4 (game installer)
 
 ARCHIVE_BASE_EN_0_NAME='setup_escape_from_monkey_islandtm_1.1_(20987).exe'
@@ -48,9 +46,22 @@ ARCHIVE_REQUIRED_PATCH_FR_NAME='MonkeyUpdate_FRA.exe'
 ARCHIVE_REQUIRED_PATCH_FR_MD5='cc5ff3bb8f78a0eb4b8e0feb9cdd2e87'
 ARCHIVE_REQUIRED_PATCH_FR_URL='https://downloads.scummvm.org/frs/extras/patches/'
 
-# Archives content
-
 CONTENT_PATH_DEFAULT='.'
+## monkey4.exe requirements
+CONTENT_LIBS_BIN_WINE_FILES='
+mss32.dll
+binkw32.dll'
+CONTENT_GAME_BIN_WINE_FILES='
+mp3dec.asi
+monkey.exe
+monkey4.exe
+syscheck.exe
+chorus.flt
+reverb3.flt
+sdelay.flt'
+CONTENT_GAME0_BIN_WINE_PATH='__support/save'
+CONTENT_GAME0_BIN_WINE_FILES='
+saves'
 CONTENT_GAME_L10N_FILES='
 movies
 art???.m4b
@@ -66,31 +77,6 @@ CONTENT_DOC_L10N_FILES='
 *.pdf
 *.txt'
 
-## WINE
-
-CONTENT_GAME_BIN_WINE_FILES='
-mp3dec.asi
-binkw32.dll
-mss32.dll
-monkey.exe
-monkey4.exe
-syscheck.exe
-chorus.flt
-reverb3.flt
-sdelay.flt'
-CONTENT_GAME0_BIN_WINE_PATH='__support/save'
-CONTENT_GAME0_BIN_WINE_FILES='
-saves'
-
-# Launchers
-
-## ScummVM
-
-APP_SCUMMVM_SCUMMID='grim:monkey4'
-APP_SCUMMVM_ICON='monkey4.exe'
-
-## WINE
-
 USER_PERSISTENT_DIRECTORIES='
 saves'
 
@@ -103,9 +89,10 @@ WINE_REGISTRY_INIT='
 "Install path"="C:\\'"${GAME_ID}"'"'
 WINE_VIRTUAL_DESKTOP='auto'
 
-APP_WINE_EXE='monkey4.exe'
+APP_SCUMMVM_SCUMMID='grim:monkey4'
+APP_SCUMMVM_ICON='monkey4.exe'
 
-# Packages
+APP_WINE_EXE='monkey4.exe'
 
 PACKAGES_LIST='
 PKG_BIN_SCUMMVM
@@ -114,47 +101,42 @@ PKG_L10N
 PKG_DATA'
 
 PKG_BIN_BASE_ID="$GAME_ID"
-PKG_BIN_PROVIDES="
+
+PKG_BIN_SCUMMVM_BASE_ID="${PKG_BIN_BASE_ID}-scummvm"
+PKG_BIN_SCUMMVM_ID_EN="${PKG_BIN_SCUMMVM_BASE_ID}-en"
+PKG_BIN_SCUMMVM_ID_FR="${PKG_BIN_SCUMMVM_BASE_ID}-fr"
+PKG_BIN_SCUMMVM_PROVIDES="
 $PKG_BIN_BASE_ID"
-## A dependency on the language-specific variant of the localization package is set,
-## not on the common name provided by both variants of this package.
-PKG_BIN_DEPENDENCIES_SIBLINGS='
+PKG_BIN_SCUMMVM_DESCRIPTION_EN='English version'
+PKG_BIN_SCUMMVM_DESCRIPTION_FR='French version'
+PKG_BIN_SCUMMVM_DEPENDENCIES_SIBLINGS='
 PKG_L10N
 PKG_DATA'
 
-PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_DESCRIPTION='data'
+PKG_BIN_WINE_ARCH='32'
+PKG_BIN_WINE_BASE_ID="${PKG_BIN_BASE_ID}-wine"
+PKG_BIN_WINE_ID_EN="${PKG_BIN_WINE_BASE_ID}-en"
+PKG_BIN_WINE_ID_FR="${PKG_BIN_WINE_BASE_ID}-fr"
+PKG_BIN_WINE_PROVIDES="
+$PKG_BIN_BASE_ID"
+PKG_BIN_WINE_DESCRIPTION_EN='English version'
+PKG_BIN_WINE_DESCRIPTION_FR='French version'
+PKG_BIN_WINE_DEPENDENCIES_SIBLINGS='
+PKG_L10N
+PKG_DATA'
 
 PKG_L10N_BASE_ID="${GAME_ID}-l10n"
 PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
 PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
 $PKG_L10N_BASE_ID"
-PKG_L10N_DESCRIPTION_EN='English localization'
-PKG_L10N_DESCRIPTION_FR='French localization'
+PKG_L10N_DESCRIPTION_EN='English localisation'
+PKG_L10N_DESCRIPTION_FR='French localisation'
 
-## ScummVM
+PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_DESCRIPTION='data'
 
-PKG_BIN_SCUMMVM_BASE_ID="${PKG_BIN_BASE_ID}-scummvm"
-PKG_BIN_SCUMMVM_ID_EN="${PKG_BIN_SCUMMVM_BASE_ID}-en"
-PKG_BIN_SCUMMVM_ID_FR="${PKG_BIN_SCUMMVM_BASE_ID}-fr"
-PKG_BIN_SCUMMVM_PROVIDES="$PKG_BIN_BASE_PROVIDES"
-PKG_BIN_SCUMMVM_DESCRIPTION_EN='English version'
-PKG_BIN_SCUMMVM_DESCRIPTION_FR='French version'
-PKG_BIN_SCUMMVM_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-
-## WINE
-
-PKG_BIN_WINE_ARCH='32'
-PKG_BIN_WINE_BASE_ID="${PKG_BIN_BASE_ID}-wine"
-PKG_BIN_WINE_ID_EN="${PKG_BIN_WINE_BASE_ID}-en"
-PKG_BIN_WINE_ID_FR="${PKG_BIN_WINE_BASE_ID}-fr"
-PKG_BIN_WINE_PROVIDES="$PKG_BIN_PROVIDES"
-PKG_BIN_WINE_DESCRIPTION_EN='English version'
-PKG_BIN_WINE_DESCRIPTION_FR='French version'
-PKG_BIN_WINE_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -180,11 +162,11 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Check for the presence of required extra archives
+# Check for the presence of the ScummVM patch.
 
 case "$(current_archive)" in
 	('ARCHIVE_BASE_EN_'*)
@@ -199,11 +181,11 @@ case "$(current_archive)" in
 	;;
 esac
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
@@ -212,12 +194,27 @@ install -D --mode=644 \
 	"$(archive_path 'ARCHIVE_PATCH')" \
 	"$(package_path 'PKG_BIN_SCUMMVM')$(path_game_data)/$(archive_name 'ARCHIVE_PATCH')"
 
-# Write launchers
+# Write launchers.
+
+## WINE - Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
 
 launchers_generation 'PKG_BIN_SCUMMVM' 'APP_SCUMMVM'
 launchers_generation 'PKG_BIN_WINE' 'APP_WINE'
 
-# Build packages
+# Build packages.
 
 packages_generation
 printf '\n'
@@ -226,7 +223,7 @@ print_instructions 'PKG_DATA' 'PKG_L10N' 'PKG_BIN_SCUMMVM'
 printf 'WINE:'
 print_instructions 'PKG_DATA' 'PKG_L10N' 'PKG_BIN_WINE'
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
