@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Oil Rush
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250104.1
+script_version=20250429.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='oil-rush'
 GAME_NAME='Oil Rush'
@@ -73,8 +74,6 @@ PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libdl.so.2
@@ -90,8 +89,6 @@ libXext.so.6
 libXinerama.so.1
 libXrandr.so.2
 libXrender.so.1'
-PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
-PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
