@@ -8,15 +8,13 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250713.1
+script_version=20251101.6
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='pharaoh'
 GAME_NAME='Pharaoh'
 
-# Archives
-
 ## Pharaoh + Cleopatra
 
 ARCHIVE_BASE_0_NAME='setup_pharaoh_gold_2.1.0.15.exe'
@@ -31,7 +29,13 @@ ARCHIVE_BASE_0_URL='https://www.gog.com/game/pharaoh_cleopatra'
 ## Akhenaten
 ## cf. https://github.com/dalerank/Akhenaten
 
-### release 1466 (0.2.5)
+### 0.2.6 (release 1638)
+ARCHIVE_OPTIONAL_AKHENATEN_5_NAME='akhenaten.linux'
+ARCHIVE_OPTIONAL_AKHENATEN_5_MD5='b670df5972c9d189f2eebf1df5f2bc96'
+ARCHIVE_OPTIONAL_AKHENATEN_5_SIZE='177630'
+ARCHIVE_OPTIONAL_AKHENATEN_5_URL='https://dalerank.itch.io/akhenaten'
+
+### 0.2.5 (release 1466)
 ### WARNING: This build crashes on launch with the following trace:
 ###
 ### #0  0x000055d27448a432 in sig_handler at /home/runner/work/Akhenaten/Akhenaten/src/core/log.cpp:77:49
@@ -60,7 +64,6 @@ ARCHIVE_BASE_0_URL='https://www.gog.com/game/pharaoh_cleopatra'
 ARCHIVE_OPTIONAL_AKHENATEN_4_NAME='akhenaten.linux'
 ARCHIVE_OPTIONAL_AKHENATEN_4_MD5='a7e38f4e0863065754817285e193752b'
 ARCHIVE_OPTIONAL_AKHENATEN_4_SIZE='126251'
-ARCHIVE_OPTIONAL_AKHENATEN_4_URL='https://dalerank.itch.io/akhenaten'
 
 ### release 1036
 ARCHIVE_OPTIONAL_AKHENATEN_3_NAME='akhenaten.linux'
@@ -83,12 +86,13 @@ ARCHIVE_OPTIONAL_AKHENATEN_0_MD5='7e52e2e90f5b00069cd312507d55c518'
 ARCHIVE_OPTIONAL_AKHENATEN_0_SIZE='31820'
 
 CONTENT_PATH_DEFAULT='app'
+## Pharaoh.exe requirements
+CONTENT_LIBS_BIN_WINE_FILES='
+smackw32.dll
+mss32.dll
+binkw32.dll'
 CONTENT_GAME_BIN_WINE_FILES='
 MP3DEC.ASI
-BINKW32.DLL
-mss16.dll
-mss32.dll
-SMACKW32.DLL
 Pharaoh.exe
 Pharaoh.ini
 mssb16.tsk
@@ -125,9 +129,11 @@ Save'
 USER_PERSISTENT_FILES='
 *.ini'
 
-## WINE - With the default OpenGL renderer, the game menu is not displayed (WINE 9.0).
+## WINE - With the default OpenGL renderer, the game menu is not displayed.
+## (WINE 9.0)
 WINE_DIRECT3D_RENDERER='wined3d/gdi'
-## WINE - The game window fails to render anything unless the game runs in a WINE virtual desktop (WINE 9.0).
+## WINE - The game window fails to render anything unless the game runs in a WINE virtual desktop.
+## (WINE 9.0)
 WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE_BIN_LINUX='akhenaten.linux'
@@ -156,9 +162,10 @@ PKG_BIN_LINUX_DEPENDENCIES_LIBRARIES='
 libc.so.6
 libm.so.6
 libSDL2-2.0.so.0
-libSDL2_mixer-2.0.so.0'
-## Ensure smooth upgrades from packages generated with pre-20231105.3 game scripts
-PKG_BIN_LINUX_PROVIDES="${PKG_BIN_LINUX_PROVIDES:-}
+libSDL2_mixer-2.0.so.0
+libz.so.1'
+## Easier upgrades from pre-20231105.3 packages
+PKG_BIN_LINUX_PROVIDES="$PKG_BIN_LINUX_PROVIDES
 pharaoh-ozymandias"
 
 PKG_BIN_WINE_ID="${PKG_BIN_ID}-wine"
@@ -170,7 +177,7 @@ PKG_BIN_WINE_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -196,10 +203,11 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Check for the presence of the Akhenaten native engine binary (optional)
+# Check for the presence of the Akhenaten native engine binary (optional).
 
 archive_initialize_optional \
 	'ARCHIVE_AKHENATEN' \
+	'ARCHIVE_OPTIONAL_AKHENATEN_5' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_4' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_3' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_2' \
@@ -209,15 +217,15 @@ if archive_is_available 'ARCHIVE_AKHENATEN'; then
 	export PACKAGES_LIST="$PACKAGES_LIST_AKHENATEN"
 fi
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
@@ -231,14 +239,22 @@ if archive_is_available 'ARCHIVE_AKHENATEN'; then
 		"$(package_path 'PKG_BIN_LINUX')$(path_game_data)/${application_exe}"
 fi
 
-# Write launchers
+# Write launchers.
+
+## WINE - Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
 launchers_generation 'PKG_BIN_WINE'
 if archive_is_available 'ARCHIVE_AKHENATEN'; then
 	launchers_generation 'PKG_BIN_LINUX'
 fi
 
-# Build packages
+# Build packages.
 
 packages_generation
 printf '\n'
@@ -251,7 +267,7 @@ else
 	print_instructions
 fi
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
