@@ -14,9 +14,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250403.2
+script_version=20251008.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='pillars-of-eternity-1'
 GAME_NAME='Pillars of Eternity'
@@ -39,10 +39,13 @@ EXPANSION_NAME_TWM2='The White March Part Ⅱ'
 EXPANSION_ID_DEADFIRE='deadfire-pack'
 EXPANSION_NAME_DEADFIRE='Deadfire Pack'
 
-# Archives
-
 ## Kickstarter item
 
+ARCHIVE_BASE_TIER1BACKER_2_NAME='pillars_of_eternity_kickstarter_item_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_TIER1BACKER_2_MD5='89b14ee2a9497afc1a546192b3de5b5b'
+ARCHIVE_BASE_TIER1BACKER_2_SIZE='971'
+ARCHIVE_BASE_TIER1BACKER_2_VERSION='3.8.0.88149-gog85633'
+
 ARCHIVE_BASE_TIER1BACKER_1_NAME='pillars_of_eternity_kickstarter_item_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_TIER1BACKER_1_MD5='67b7ae65b7c1502e37110b7f4402a19f'
 ARCHIVE_BASE_TIER1BACKER_1_SIZE='971'
@@ -55,6 +58,11 @@ ARCHIVE_BASE_TIER1BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Kickstarter pet
 
+ARCHIVE_BASE_TIER2BACKER_2_NAME='pillars_of_eternity_kickstarter_pet_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_TIER2BACKER_2_MD5='4011745c101d3df071e6a359ff6f499b'
+ARCHIVE_BASE_TIER2BACKER_2_SIZE='978'
+ARCHIVE_BASE_TIER2BACKER_2_VERSION='3.8.0.88149-gog85633'
+
 ARCHIVE_BASE_TIER2BACKER_1_NAME='pillars_of_eternity_kickstarter_pet_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_TIER2BACKER_1_MD5='f5ee7919aaf466d45c12689a4de327e9'
 ARCHIVE_BASE_TIER2BACKER_1_SIZE='978'
@@ -67,6 +75,11 @@ ARCHIVE_BASE_TIER2BACKER_0_VERSION='1.0-gog2.0.0.2'
 
 ## Pre-order item and pet
 
+ARCHIVE_BASE_PREORDER_2_NAME='pillars_of_eternity_preorder_item_and_pet_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_PREORDER_2_MD5='7bced964b41788b3c066fd58a9fbb58d'
+ARCHIVE_BASE_PREORDER_2_SIZE='963'
+ARCHIVE_BASE_PREORDER_2_VERSION='3.8.0.88149-gog85633'
+
 ARCHIVE_BASE_PREORDER_1_NAME='pillars_of_eternity_preorder_item_and_pet_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_PREORDER_1_MD5='ad7a6c20a937f76a356e1613495c43c0'
 ARCHIVE_BASE_PREORDER_1_SIZE='963'
@@ -79,11 +92,16 @@ ARCHIVE_BASE_PREORDER_0_VERSION='1.0-gog2.0.0.2'
 
 ## The White March, Part 1
 
+ARCHIVE_BASE_TWM1_5_NAME='pillars_of_eternity_the_white_march_part_1_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_TWM1_5_MD5='13a423d8622a3251aefc0a6254e1421c'
+ARCHIVE_BASE_TWM1_5_SIZE='7564726'
+ARCHIVE_BASE_TWM1_5_VERSION='3.8.0.88149-gog85633'
+ARCHIVE_BASE_TWM1_5_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_1'
+
 ARCHIVE_BASE_TWM1_4_NAME='pillars_of_eternity_the_white_march_part_1_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_TWM1_4_MD5='ad2218672a0aba7ee0a30b73eefc81dd'
 ARCHIVE_BASE_TWM1_4_SIZE='7564726'
 ARCHIVE_BASE_TWM1_4_VERSION='3.8.0.87535-gog80946'
-ARCHIVE_BASE_TWM1_4_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_1'
 
 ARCHIVE_BASE_TWM1_3_NAME='pillars_of_eternity_white_march_part_1_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM1_3_MD5='cc72f59ee20238ff05c47646b4618f01'
@@ -107,11 +125,16 @@ ARCHIVE_BASE_TWM1_0_VERSION='3.05.0.1186-gog2.9.0.11'
 
 ## The White March, Part 2
 
+ARCHIVE_BASE_TWM2_5_NAME='pillars_of_eternity_the_white_march_part_2_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_TWM2_5_MD5='90a7c82b7dab1939af91110b87248015'
+ARCHIVE_BASE_TWM2_5_SIZE='6845084'
+ARCHIVE_BASE_TWM2_5_VERSION='3.8.0.88149-gog85633'
+ARCHIVE_BASE_TWM2_5_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_2'
+
 ARCHIVE_BASE_TWM2_4_NAME='pillars_of_eternity_the_white_march_part_2_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_TWM2_4_MD5='b64f8528243197aaec1a6a99fb43e728'
 ARCHIVE_BASE_TWM2_4_SIZE='6845084'
 ARCHIVE_BASE_TWM2_4_VERSION='3.8.0.87535-gog80946'
-ARCHIVE_BASE_TWM2_4_URL='https://www.gog.com/game/pillars_of_eternity_the_white_march_part_2'
 
 ARCHIVE_BASE_TWM2_3_NAME='pillars_of_eternity_white_march_part_2_dlc_en_3_07_0_1318_17464.sh'
 ARCHIVE_BASE_TWM2_3_MD5='03067ebdd878cc16c283f63ddf015e90'
@@ -135,11 +158,16 @@ ARCHIVE_BASE_TWM2_0_VERSION='3.05.1186-gog2.5.0.6'
 
 ## Deadfire Pack
 
+ARCHIVE_BASE_DEADFIRE_4_NAME='pillars_of_eternity_deadfire_pack_3_8_0_88149_85633.sh'
+ARCHIVE_BASE_DEADFIRE_4_MD5='5cb48dd4e262a46c9fc74ee760d0325e'
+ARCHIVE_BASE_DEADFIRE_4_SIZE='73988'
+ARCHIVE_BASE_DEADFIRE_4_VERSION='3.8.0.88149-gog85633'
+ARCHIVE_BASE_DEADFIRE_4_URL='https://www.gog.com/game/pillars_of_eternity_deadfire_pack'
+
 ARCHIVE_BASE_DEADFIRE_3_NAME='pillars_of_eternity_deadfire_pack_3_8_0_87535_80946.sh'
 ARCHIVE_BASE_DEADFIRE_3_MD5='ece6e59bc5bd1f59498140d3a4f1fb74'
 ARCHIVE_BASE_DEADFIRE_3_SIZE='73988'
 ARCHIVE_BASE_DEADFIRE_3_VERSION='3.8.0.87535-gog80946'
-ARCHIVE_BASE_DEADFIRE_3_URL='https://www.gog.com/game/pillars_of_eternity_deadfire_pack'
 
 ARCHIVE_BASE_DEADFIRE_2_NAME='pillars_of_eternity_deadfire_pack_dlc_en_3_07_0_1318_20099.sh'
 ARCHIVE_BASE_DEADFIRE_2_MD5='da315aba26784e55aa51139cebb7f9d2'
@@ -175,7 +203,7 @@ PKG_PARENT'
 PKG_MAIN_DEPENDENCIES_SIBLINGS_TWM2="$PKG_MAIN_DEPENDENCIES_SIBLINGS
 PKG_TWM1"
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -201,45 +229,40 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+case "$(current_archive)" in
+	## The White March, Part 2 - Remove files already provided by a dependency.
+	('ARCHIVE_BASE_TWM2_'*)
+		rm --force \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror" \
+			"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror.unity3d"
+	;;
+	## Deadfire Pack - Fix a typo in a file path.
+	('ARCHIVE_BASE_DEADFIRE_'*)
+		if [ -e "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/PillarsOfEternity_data" ]; then
+			mv \
+				"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/PillarsOfEternity_data" \
+				"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/PillarsOfEternity_Data"
+		fi
+	;;
+esac
 
-	# The White March, Part 2 - Remove a file already provided by a dependency
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_TWM2_'*)
-			rm --force \
-				'PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror' \
-				'PillarsOfEternity_Data/assetbundles/prefabs/objectbundle/px1_cre_blight_ice_terror.unity3d'
-		;;
-	esac
-
-	# Deadfire Pack - Fix a typo in a file path
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_DEADFIRE_'*)
-			if [ -e 'PillarsOfEternity_data' ]; then
-				mv 'PillarsOfEternity_data' 'PillarsOfEternity_Data'
-			fi
-		;;
-	esac
-)
-
-# Include game data
+# Include game data.
 
 content_inclusion_default
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
