@@ -8,9 +8,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241125.1
+script_version=20251108.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='prince-of-persia-the-sands-of-time'
 GAME_NAME='Prince of Persia: The Sands of Time'
@@ -34,26 +34,27 @@ ARCHIVE_BASE_EN_0_VERSION='1.00.181-gog28548'
 ARCHIVE_BASE_EN_0_URL='https://www.gog.com/game/prince_of_persia_the_sands_of_time'
 
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_BIN_FILES='
+CONTENT_LIBS_BIN_FILES='
 binkw32.dll
-detectionapi.dll
-directx8tests.dll
-directx9tests.dll
 eax.dll
-mfc71.dll
-msvcp71.dll
-msvcr71.dll
+MFC71.DLL'
+## Required for hardware detection on launch
+CONTENT_LIBS0_BIN_FILES='
+detectionapi.dll
+directx9tests.dll'
+## Localised error messages are included in this library.
+CONTENT_LIBS_L10N_LIBS_FILES='
+poplauncherres.dll'
+CONTENT_GAME_BIN_FILES='
 pop.exe
 princeofpersia.exe
 directxtests.tst
 systemtests.tst'
 CONTENT_GAME0_BIN_PATH='__support/app'
-## "Hardware.ini" instead of "hardware.ini" is not a typo.
 CONTENT_GAME0_BIN_FILES='
 Hardware.ini
 sound/dare.ini'
 CONTENT_GAME_L10N_FILES='
-poplauncherres.dll
 popdata.bf
 sound/soundlocal.big
 sound/soundlocal.fat
@@ -75,11 +76,11 @@ USER_PERSISTENT_DIRECTORIES='
 profiles'
 
 APP_MAIN_EXE='princeofpersia.exe'
-## Work around fog rendering problems
+## Work around fog rendering problems.
 ## On first launch, the game runs with display problems related to fog rendering.
 ## Quit the game and launch it again, it should automatically be fixed on the second launch.
 APP_MAIN_PRERUN='
-# Work around fog rendering problems
+# Work around fog rendering problems.
 # On first launch, the game runs with display problems related to fog rendering.
 # Quit the game and launch it again, it should automatically be fixed on the second launch.
 config_file="Hardware.ini"
@@ -90,9 +91,9 @@ sed \
 	"$config_file"
 unix2dos --quiet "$config_file"
 '
-## Work around an override of configuration file
+## Work around an override of configuration file.
 APP_MAIN_POSTRUN='
-# Work around an override of configuration file
+# Work around an override of configuration file.
 config_file="Hardware.ini"
 config_file_persistent="${PATH_PERSISTENT}/${config_file}"
 if \
@@ -108,37 +109,50 @@ fi
 PACKAGES_LIST='
 PKG_BIN
 PKG_L10N
+PKG_L10N_LIBS
 PKG_DATA'
 
 PKG_BIN_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_L10N_BASE
 PKG_DATA'
-## Work around fog rendering problems
-PKG_BIN_DEPENDENCIES_COMMANDS="${PKG_BIN_DEPENDENCIES_COMMANDS:-}
-dos2unix"
-## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
-PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
-prince-of-persia"
+## Work around fog rendering problems.
+PKG_BIN_DEPENDENCIES_COMMANDS='
+dos2unix'
+## Easier upgrades from pre-20231018.1 packages
+PKG_BIN_PROVIDES='
+prince-of-persia'
 
 PKG_L10N_BASE_ID="${GAME_ID}-l10n"
 PKG_L10N_ID_EN="${PKG_L10N_BASE_ID}-en"
 PKG_L10N_ID_FR="${PKG_L10N_BASE_ID}-fr"
 PKG_L10N_PROVIDES="
 $PKG_L10N_BASE_ID"
-PKG_L10N_DESCRIPTION_EN='English localization'
-PKG_L10N_DESCRIPTION_FR='French localization'
-## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
-PKG_L10N_PROVIDES="${PKG_L10N_PROVIDES:-}
+PKG_L10N_DESCRIPTION_EN='English localisation'
+PKG_L10N_DESCRIPTION_FR='French localisation'
+PKG_L10N_DEPENDENCIES_SIBLINGS='
+PKG_L10N_LIBS'
+## Easier upgrades from pre-20231018.1 packages
+PKG_L10N_PROVIDES="$PKG_L10N_PROVIDES
 prince-of-persia-l10n"
 
+PKG_L10N_LIBS_ID_EN="${PKG_L10N_ID_EN}-libs"
+PKG_L10N_LIBS_ID_FR="${PKG_L10N_ID_FR}-libs"
+PKG_L10N_LIBS_PROVIDES="
+${PKG_L10N_BASE_ID}-libs"
+PKG_L10N_LIBS_ARCH='32'
+PKG_L10N_LIBS_DESCRIPTION_EN="$PKG_L10N_DESCRIPTION_EN - libraries"
+PKG_L10N_LIBS_DESCRIPTION_FR="$PKG_L10N_DESCRIPTION_FR - libraries"
+## Prevent a fallback on PKG_L10N_DEPENDENCIES_SIBLINGS.
+PKG_L10N_LIBS_DEPENDENCIES_SIBLINGS=' '
+
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
-## Ensure a smooth upgrade from packages generated with pre-20231018.1 scripts.
-PKG_DATA_PROVIDES="${PKG_DATA_PROVIDES:-}
-prince-of-persia-data"
+## Easier upgrades from pre-20231018.1 packages
+PKG_DATA_PROVIDES='
+prince-of-persia-data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -164,35 +178,43 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME0_BIN')"
 
-	# Work around case-related problems caused by file deletion-creation instead of in-place edition
-	mv 'hardware.ini' 'Hardware.ini'
-)
+# Work around case-related problems caused by file deletion-creation instead of in-place edition.
 
-# Include game data
+mv \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME0_BIN')/hardware.ini" \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path 'GAME0_BIN')/Hardware.ini"
+
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
