@@ -9,7 +9,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250721.1
+script_version=20251103.5
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -74,45 +74,22 @@ ARCHIVE_BASE_WINDOWS_0_SIZE='1114877'
 ARCHIVE_BASE_WINDOWS_0_VERSION='525-gog46550'
 ARCHIVE_BASE_WINDOWS_0_URL='https://www.gog.com/game/renowned_explorers'
 
+CONTENT_PATH_DEFAULT_LINUX='data/noarch/game'
+CONTENT_PATH_DEFAULT_WINDOWS='.'
+## abbeycore_win32.exe reqiorements
+CONTENT_LIBS_BIN_FILES_WINDOWS='
+win64/Galaxy64.dll
+win64/amd_ags_x64.dll'
+CONTENT_GAME_BIN_FILES_LINUX='
+x86_64/abbeycore'
+CONTENT_GAME_BIN_FILES_WINDOWS='
+win64/abbeycore_win32.exe'
 CONTENT_GAME_DATA_FILES='
 data
 soundbanks
 settings.ini
 *.bni'
 
-CONTENT_PATH_DEFAULT_LINUX='data/noarch/game'
-CONTENT_GAME_BIN64_FILES_LINUX='
-x86_64/abbeycore'
-CONTENT_GAME_BIN32_FILES_LINUX='
-x86/abbeycore'
-
-CONTENT_PATH_DEFAULT_WINDOWS='.'
-CONTENT_GAME_BIN64_FILES_WINDOWS='
-win64/amd_ags_x64.dll
-win64/d3d11.dll
-win64/d3dcompiler_47.dll
-win64/dxgi.dll
-win64/abbeycore_win32.exe'
-## The Windows build fails to start if the GOG Galaxy librarie are not included.
-CONTENT_GAME0_BIN64_FILES_WINDOWS='
-win64/galaxy64.dll
-win64/galaxypeer64.dll
-win64/goggalaxyhooks.dll'
-CONTENT_GAME_BIN32_FILES_WINDOWS='
-win32/amd_ags_x86.dll
-win32/d3d11.dll
-win32/d3dcompiler_47.dll
-win32/dxgi.dll
-win32/abbeycore_win32.exe'
-## The Windows build fails to start if the GOG Galaxy librarie are not included.
-CONTENT_GAME0_BIN32_FILES_WINDOWS='
-win32/galaxy.dll
-win32/galaxypeer.dll
-win32/goggalaxyhooks.dll'
-
-## The game renders only a black screen and the mouse cursor
-## when using the default wined3d renderer (WINE 10.0).
-WINE_DIRECT3D_RENDERER='dxvk'
 WINE_PERSISTENT_DIRECTORIES='
 users/${USER}/Documents/Renowned Explorers International Society'
 
@@ -122,21 +99,18 @@ USER_PERSISTENT_DIRECTORIES_LINUX='
 savedata
 userdata'
 
-APP_MAIN_EXE_BIN64_LINUX='x86_64/abbeycore'
-APP_MAIN_EXE_BIN64_WINDOWS='win64/abbeycore_win32.exe'
-APP_MAIN_EXE_BIN32_LINUX='x86/abbeycore'
-APP_MAIN_EXE_BIN32_WINDOWS='win32/abbeycore_win32.exe'
+APP_MAIN_EXE_LINUX='x86_64/abbeycore'
+APP_MAIN_EXE_WINDOWS='win64/abbeycore_win32.exe'
 APP_MAIN_ICON_LINUX='../support/icon.png'
 APP_MAIN_ICON_WINDOWS='app/goggame-1435329098.ico'
-## Work around inconsistent behaviour with some locales
+## Work around inconsistent behaviour with some locales.
 APP_MAIN_PRERUN='
-# Work around inconsistent behaviour with some locales
+# Work around inconsistent behaviour with some locales.
 export LANG=C
 '
 
 PACKAGES_LIST='
-PKG_BIN64
-PKG_BIN32
+PKG_BIN
 PKG_DATA'
 
 PKG_BIN_ID="${GAME_ID}-bin"
@@ -144,8 +118,7 @@ PKG_BIN_ID_LINUX="${PKG_BIN_ID}-linux"
 PKG_BIN_ID_WINDOWS="${PKG_BIN_ID}-windows"
 PKG_BIN_PROVIDES="
 $PKG_BIN_ID"
-PKG_BIN64_ARCH='64'
-PKG_BIN32_ARCH='32'
+PKG_BIN_ARCH='64'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES_LINUX='
@@ -162,8 +135,8 @@ libSDL2-2.0.so.0
 libX11.so.6
 libXcursor.so.1
 libXrandr.so.2'
-## Ensure easy upgrades from packages generated with pre-20250104.1 game scripts
-PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
+## EAsier upgrades from pre-20250104.1 packages
+PKG_BIN_PROVIDES="$PKG_BIN_PROVIDES
 renowned-explorers"
 
 PKG_DATA_ID="${GAME_ID}-data"
@@ -173,7 +146,7 @@ PKG_DATA_PROVIDES="
 $PKG_DATA_ID"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -199,32 +172,44 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-APP_MAIN_EXE_BIN64=$(context_value 'APP_MAIN_EXE_BIN64')
-APP_MAIN_EXE_BIN32=$(context_value 'APP_MAIN_EXE_BIN32')
-launchers_generation 'PKG_BIN64'
-launchers_generation 'PKG_BIN32'
+## WINE - Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
