@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Scrapland
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250104.1
+script_version=20250721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='scrapland'
 GAME_NAME='Scrapland'
@@ -52,8 +53,6 @@ CONTENT_VIDEO_L10N_FR_FILES='
 
 WINE_PERSISTENT_DIRECTORIES='
 users/${USER}/Documents/MercurySteam/Scrapland'
-## TODO: Check if the virtual desktop is still required with current WINE
-WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE='bin/scrap.exe'
 
@@ -78,8 +77,6 @@ PKG_L10N_EN_ID="${PKG_L10N_ID}-en"
 PKG_L10N_FR_ID="${PKG_L10N_ID}-fr"
 PKG_L10N_PROVIDES="
 $PKG_L10N_ID"
-PKG_L10N_EN_PROVIDES="$PKG_L10N_PROVIDES"
-PKG_L10N_FR_PROVIDES="$PKG_L10N_PROVIDES"
 PKG_L10N_EN_DESCRIPTION='English localization'
 PKG_L10N_FR_DESCRIPTION='English localization'
 
