@@ -8,13 +8,22 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250626.1
+script_version=20251121.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='songs-of-conquest'
 GAME_NAME='Songs of Conquest'
 
+ARCHIVE_BASE_9_NAME='setup_songs_of_conquest_1.7.3_d817094042_3758_(86541).exe'
+ARCHIVE_BASE_9_MD5='dc5e2e5605a2cf2fa9b7357196be0dab'
+ARCHIVE_BASE_9_TYPE='innosetup'
+ARCHIVE_BASE_9_PART1_NAME='setup_songs_of_conquest_1.7.3_d817094042_3758_(86541)-1.bin'
+ARCHIVE_BASE_9_PART1_MD5='2d4ed6f931e478c6590ac28e09211e05'
+ARCHIVE_BASE_9_SIZE='2357821'
+ARCHIVE_BASE_9_VERSION='1.7.3-gog86541'
+ARCHIVE_BASE_9_URL='https://www.gog.com/game/songs_of_conquest'
+
 ARCHIVE_BASE_8_NAME='setup_songs_of_conquest_1.6.1_1c165726cf_3547_(83102).exe'
 ARCHIVE_BASE_8_MD5='1d02d310853568e03a6e052960844841'
 ARCHIVE_BASE_8_TYPE='innosetup'
@@ -108,7 +117,7 @@ video/quicktime, variant=(string)iso'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -134,29 +143,29 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+launchers_generation
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
