@@ -8,9 +8,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250306.2
+script_version=20251114.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='starcraft'
 GAME_NAME='StarCraft'
@@ -39,13 +39,21 @@ ARCHIVE_REQUIRED_UPDATE_VERSION='1.17.0-blizzard1'
 ARCHIVE_REQUIRED_UPDATE_URL='https://downloads.dotslashplay.it/games/starcraft/'
 
 CONTENT_PATH_DEFAULT='.'
+## The game fails to launch if the following library is missing.
+CONTENT_LIBS_BIN_PATH='PC'
+CONTENT_LIBS_BIN_FILES='
+Local.dll'
+## The editor fails to launch if the following library is missing.
+CONTENT_LIBS0_BIN_PATH='PC'
+CONTENT_LIBS0_BIN_FILES='
+EditLocal.dll'
+## The game crashes on launch if the following library is missing.
+CONTENT_LIBS1_BIN_PATH='PC'
+CONTENT_LIBS1_BIN_FILES='
+Smackw32.dll'
 CONTENT_GAME_BIN_PATH='PC'
 CONTENT_GAME_BIN_FILES='
-*.snp
-*.dll
-*.exe
-*.loc
-*.mpq'
+SEdit???.loc'
 CONTENT_GAME_DATA_PATH='Common'
 CONTENT_GAME_DATA_FILES='
 Maps
@@ -59,13 +67,12 @@ CONTENT_DOC_DATA_FILES='
 *.url'
 
 CONTENT_UPDATE_PATH='.'
+## StarCraft.exe requirements
+CONTENT_UPDATE_LIBS_FILES='
+Storm.dll'
 CONTENT_UPDATE_GAME_FILES='
-storm.dll
-BlizzardError.exe
-bnupdate.exe
 StarCraft.exe
 StarEdit.exe
-SystemSurvey.exe
 Patch_rt.mpq
 battle.snp
 standard.snp'
@@ -73,7 +80,6 @@ CONTENT_UPDATE_DOC_FILES='
 patch.txt'
 
 APP_MAIN_EXE='StarCraft.exe'
-APP_MAIN_ICON='PC/StarCraft.exe'
 
 USER_PERSISTENT_DIRECTORIES='
 Characters
@@ -94,12 +100,12 @@ PKG_DATA_PROVIDES="
 $PKG_DATA_BASE_ID"
 PKG_DATA_DESCRIPTION='data'
 
-# Set list of requirements to extract the archive data
+# Set list of requirements to extract the archive data.
 
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-smpq"
+REQUIREMENTS_LIST='
+smpq'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -125,11 +131,11 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Check for the presence of the CD key files
+# Check for the presence of the CD key files.
 
 ## During a regular install of StarCraft, CD keys are stored encrypted into StarDat.mpq,
 ## in the files under the "font" directory.
@@ -150,27 +156,27 @@ archive_initialize_required \
 	'ARCHIVE_CDKEY_2' \
 	'ARCHIVE_REQUIRED_CDKEY_2'
 
-# Check for the presence of the 1.17.0 update archive
+# Check for the presence of the 1.17.0 update archive.
 
 archive_initialize_required \
 	'ARCHIVE_UPDATE' \
 	'ARCHIVE_REQUIRED_UPDATE'
 
-export "$(current_archive)_VERSION=$ARCHIVE_REQUIRED_UPDATE_VERSION"
+export "$(current_archive)_VERSION=$(archive_version 'ARCHIVE_UPDATE')"
 
-# Extract game data
+# Extract game data.
 
 mkdir --parents "${PLAYIT_WORKDIR}/gamedata"
 (
 	cd "${PLAYIT_WORKDIR}/gamedata"
 
-	# Extract the content from the installer
+	# Extract the content from the installer.
 	information_archive_data_extraction "$(archive_name "$(current_archive)")"
 	smpq --extract "$(archive_path "$(current_archive)")"
 	information_archive_data_extraction "$(archive_name "$(current_archive)_PART1")"
 	smpq --extract --overwrite "$(archive_path "$(current_archive)_PART1")"
 
-	# Include the CD key files
+	# Include the CD key files.
 	install -D --mode=644 \
 		"$(archive_path 'ARCHIVE_CDKEY_1')" \
 		"${PLAYIT_WORKDIR}/gamedata/Files/font/font.clh"
@@ -178,7 +184,7 @@ mkdir --parents "${PLAYIT_WORKDIR}/gamedata"
 		"$(archive_path 'ARCHIVE_CDKEY_2')" \
 		"${PLAYIT_WORKDIR}/gamedata/Files/font/font.gid"
 
-	# Update the main .mpq file
+	# Update the main .mpq file.
 	(
 		cd 'PC'
 		smpq --append ../Common/StarDat.mpq \
@@ -199,20 +205,20 @@ mkdir --parents "${PLAYIT_WORKDIR}/gamedata"
 			standard.snp \
 			License.txt \
 			./*.hlp
-		## This file is only included in the English build of the game
+		## This file is only included in the English build of the game.
 		case "$(current_archive)" in
 			('ARCHIVE_BASE_EN_'*)
 				smpq --append ../Common/StarDat.mpq \
 					rez/License.txt
 			;;
 		esac
-		## Compression must be disabled when adding this file to the .mpq archive, to prevent a crash on launch
+		## Compression must be disabled when adding this file to the .mpq archive, to prevent a crash on launch.
 		smpq --append --compression none ../Common/StarDat.mpq \
 			Smk/Blizzard.smk
 	)
 	(
 		cd 'Files'
-		## Compression must be disabled when adding these files to the .mpq archive, to prevent a crash on launch
+		## Compression must be disabled when adding these files to the .mpq archive, to prevent a crash on launch.
 		smpq --append --compression none ../Common/StarDat.mpq \
 			font/*.fnt \
 			font/font.ccd \
@@ -220,36 +226,35 @@ mkdir --parents "${PLAYIT_WORKDIR}/gamedata"
 			font/font.gid
 	)
 )
-
-# Include game data
-
-content_inclusion_icons 'PKG_DATA'
-content_inclusion_default
-
-# Extract update data
-
+## Extract patch data.
 archive_extraction 'ARCHIVE_UPDATE'
 
-# Include patch data
-
-## Delete a duplicated file
-rm "$(package_path 'PKG_BIN')$(path_game_data)/patch_rt.mpq"
+# Include game data.
 
+content_inclusion_icons 'PKG_DATA'
+content_inclusion 'UPDATE_LIBS' 'PKG_BIN' "$(path_libraries)"
 content_inclusion 'UPDATE_GAME' 'PKG_BIN' "$(path_game_data)"
 content_inclusion 'UPDATE_DOC' 'PKG_DATA' "$(path_documentation)"
+content_inclusion_default
 
-rm --force --recursive "${PLAYIT_WORKDIR}/gamedata"
+# Write launchers.
 
-# Write launchers
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-launchers_generation 'PKG_BIN'
+launchers_generation
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
