@@ -11,7 +11,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250917.1
+script_version=20251120.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -27,15 +27,18 @@ EXPANSION_NAME_HORIZONSIGNAL='Horizon Signal'
 EXPANSION_ID_ANNIVERSARY='anniversary'
 EXPANSION_NAME_ANNIVERSARY='Anniversary Portraits'
 
-# Archives
-
 ## Arachnoid Portrait Pack
 
+ARCHIVE_BASE_ARACHNOID_66_NAME='stellaris_arachnoid_portrait_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_ARACHNOID_66_MD5='841c9caa537685374a25afffcda4a83d'
+ARCHIVE_BASE_ARACHNOID_66_SIZE='817'
+ARCHIVE_BASE_ARACHNOID_66_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_ARACHNOID_66_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
+
 ARCHIVE_BASE_ARACHNOID_65_NAME='stellaris_arachnoid_portrait_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_ARACHNOID_65_MD5='6348fc2d97141925913bbada9ad78f9c'
 ARCHIVE_BASE_ARACHNOID_65_SIZE='817'
 ARCHIVE_BASE_ARACHNOID_65_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_ARACHNOID_65_URL='https://www.gog.com/game/stellaris_galaxy_edition_upgrade_pack'
 
 ARCHIVE_BASE_ARACHNOID_64_NAME='stellaris_arachnoid_portrait_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_ARACHNOID_64_MD5='4168a3e72b2c19b0e7072e381b235314'
@@ -114,11 +117,16 @@ ARCHIVE_BASE_ARACHNOID_22_VERSION='3.0.3-gog47193'
 
 ## Horizon Signal
 
+ARCHIVE_BASE_HORIZONSIGNAL_66_NAME='stellaris_horizon_signal_4_1_7_86266.sh'
+ARCHIVE_BASE_HORIZONSIGNAL_66_MD5='d2411d879d8faa982c985b9f5bbc0681'
+ARCHIVE_BASE_HORIZONSIGNAL_66_SIZE='817'
+ARCHIVE_BASE_HORIZONSIGNAL_66_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_HORIZONSIGNAL_66_URL='https://www.gog.com/game/stellaris_horizon_signal'
+
 ARCHIVE_BASE_HORIZONSIGNAL_65_NAME='stellaris_horizon_signal_4_0_23_84679.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_65_MD5='d83044063bc16d23c32fee95ecbaa5f0'
 ARCHIVE_BASE_HORIZONSIGNAL_65_SIZE='817'
 ARCHIVE_BASE_HORIZONSIGNAL_65_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_HORIZONSIGNAL_65_URL='https://www.gog.com/game/stellaris_horizon_signal'
 
 ARCHIVE_BASE_HORIZONSIGNAL_64_NAME='stellaris_horizon_signal_3_14_1592653_81105.sh'
 ARCHIVE_BASE_HORIZONSIGNAL_64_MD5='b5f000f1f6ab8e30cb90ffffcbb07716'
