@@ -14,7 +14,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250917.1
+script_version=20251120.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -39,15 +39,18 @@ EXPANSION_NAME_AQUATICS='Aquatics Species Pack'
 EXPANSION_ID_TOXOIDS='toxoids'
 EXPANSION_NAME_TOXOIDS='Toxoids Species Pack'
 
-# Archives
-
 ## Plantoids
 
+ARCHIVE_BASE_PLANTOID_63_NAME='stellaris_plantoids_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_PLANTOID_63_MD5='da964d39609360f339e6b26046eef659'
+ARCHIVE_BASE_PLANTOID_63_SIZE='837'
+ARCHIVE_BASE_PLANTOID_63_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_PLANTOID_63_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
+
 ARCHIVE_BASE_PLANTOID_62_NAME='stellaris_plantoids_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_PLANTOID_62_MD5='d70d05409ff2c28ed9a770705945d4cc'
 ARCHIVE_BASE_PLANTOID_62_SIZE='837'
 ARCHIVE_BASE_PLANTOID_62_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_PLANTOID_62_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
 
 ARCHIVE_BASE_PLANTOID_61_NAME='stellaris_plantoids_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_PLANTOID_61_MD5='f2096d98d49833c1f900cd91b427b99d'
@@ -131,11 +134,16 @@ ARCHIVE_BASE_PLANTOID_19_VERSION='3.0.3-gog47193'
 
 ## Humanoids
 
+ARCHIVE_BASE_HUMANOIDS_63_NAME='stellaris_humanoids_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_HUMANOIDS_63_MD5='346e685e6fb7ea72defef76c9147a875'
+ARCHIVE_BASE_HUMANOIDS_63_SIZE='84675'
+ARCHIVE_BASE_HUMANOIDS_63_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_HUMANOIDS_63_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
+
 ARCHIVE_BASE_HUMANOIDS_62_NAME='stellaris_humanoids_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_HUMANOIDS_62_MD5='2f24f9d1cceb67be64f932452c705c34'
 ARCHIVE_BASE_HUMANOIDS_62_SIZE='84675'
 ARCHIVE_BASE_HUMANOIDS_62_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_HUMANOIDS_62_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
 
 ARCHIVE_BASE_HUMANOIDS_61_NAME='stellaris_humanoids_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_HUMANOIDS_61_MD5='b0ca9dba864d8726f822b03749cc680c'
@@ -214,11 +222,16 @@ ARCHIVE_BASE_HUMANOIDS_19_VERSION='3.0.3-gog47193'
 
 ## Lithoids
 
+ARCHIVE_BASE_LITHOIDS_51_NAME='stellaris_lithoids_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_LITHOIDS_51_MD5='c78d3a9acde2188800455c96e272e52e'
+ARCHIVE_BASE_LITHOIDS_51_SIZE='25612'
+ARCHIVE_BASE_LITHOIDS_51_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_LITHOIDS_51_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
+
 ARCHIVE_BASE_LITHOIDS_50_NAME='stellaris_lithoids_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_LITHOIDS_50_MD5='15878fe6dfb2d5e9d8828f250666b5b9'
 ARCHIVE_BASE_LITHOIDS_50_SIZE='25612'
 ARCHIVE_BASE_LITHOIDS_50_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_LITHOIDS_50_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
 
 ARCHIVE_BASE_LITHOIDS_49_NAME='stellaris_lithoids_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_LITHOIDS_49_MD5='61bc2f350ab85060fa192a4ab9d0449f'
@@ -297,11 +310,16 @@ ARCHIVE_BASE_LITHOIDS_7_VERSION='3.0.3-gog47193'
 
 ## Necroids
 
+ARCHIVE_BASE_NECROIDS_36_NAME='stellaris_necroids_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_NECROIDS_36_MD5='e6088f1ade97f4687d493b11950d1123'
+ARCHIVE_BASE_NECROIDS_36_SIZE='24881'
+ARCHIVE_BASE_NECROIDS_36_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_NECROIDS_36_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
+
 ARCHIVE_BASE_NECROIDS_35_NAME='stellaris_necroids_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_NECROIDS_35_MD5='92999234cfe7eb8b4cb44c4db34d83cb'
 ARCHIVE_BASE_NECROIDS_35_SIZE='24881'
 ARCHIVE_BASE_NECROIDS_35_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_NECROIDS_35_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
 
 ARCHIVE_BASE_NECROIDS_34_NAME='stellaris_necroids_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_NECROIDS_34_MD5='5725e03dc497001f9837877ea2beff8d'
@@ -360,11 +378,16 @@ ARCHIVE_BASE_NECROIDS_2_VERSION='3.4.5-gog56913'
 
 ## Aquatics
 
+ARCHIVE_BASE_AQUATICS_34_NAME='stellaris_aquatics_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_AQUATICS_34_MD5='d53e18b0df2241c89cb3cac289e03543'
+ARCHIVE_BASE_AQUATICS_34_SIZE='29883'
+ARCHIVE_BASE_AQUATICS_34_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_AQUATICS_34_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
+
 ARCHIVE_BASE_AQUATICS_33_NAME='stellaris_aquatics_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_AQUATICS_33_MD5='1afeabca087501eae22ce82015866966'
 ARCHIVE_BASE_AQUATICS_33_SIZE='29883'
 ARCHIVE_BASE_AQUATICS_33_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_AQUATICS_33_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
 
 ARCHIVE_BASE_AQUATICS_32_NAME='stellaris_aquatics_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_AQUATICS_32_MD5='1eda07287d1d1fe6bf6cefcf2c142d8e'
@@ -423,11 +446,16 @@ ARCHIVE_BASE_AQUATICS_0_VERSION='3.4.5-gog56913'
 
 ## Toxoids
 
+ARCHIVE_BASE_TOXOIDS_27_NAME='stellaris_toxoids_species_pack_4_1_7_86266.sh'
+ARCHIVE_BASE_TOXOIDS_27_MD5='b13f2b899f909e54389a093234813d38'
+ARCHIVE_BASE_TOXOIDS_27_SIZE='21991'
+ARCHIVE_BASE_TOXOIDS_27_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_TOXOIDS_27_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
+
 ARCHIVE_BASE_TOXOIDS_26_NAME='stellaris_toxoids_species_pack_4_0_23_84679.sh'
 ARCHIVE_BASE_TOXOIDS_26_MD5='5959517aa87e401b89e3dad77fc6fca5'
 ARCHIVE_BASE_TOXOIDS_26_SIZE='21991'
 ARCHIVE_BASE_TOXOIDS_26_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_TOXOIDS_26_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
 
 ARCHIVE_BASE_TOXOIDS_25_NAME='stellaris_toxoids_species_pack_3_14_1592653_81105.sh'
 ARCHIVE_BASE_TOXOIDS_25_MD5='80a09c9500cd8afa5b1a3b0135a64223'
