@@ -18,7 +18,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250917.1
+script_version=20251120.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -55,15 +55,18 @@ EXPANSION_NAME_MACHINE='The Machine Age'
 EXPANSION_ID_STORMS='cosmic-storms'
 EXPANSION_NAME_STORMS='Cosmic Storms'
 
-# Archives
-
 ## Utopia
 
+ARCHIVE_BASE_UTOPIA_61_NAME='stellaris_utopia_4_1_7_86266.sh'
+ARCHIVE_BASE_UTOPIA_61_MD5='2e1bd4ff7aa51754c0037242f55badb3'
+ARCHIVE_BASE_UTOPIA_61_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_61_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_UTOPIA_61_URL='https://www.gog.com/game/stellaris_utopia'
+
 ARCHIVE_BASE_UTOPIA_60_NAME='stellaris_utopia_4_0_23_84679.sh'
 ARCHIVE_BASE_UTOPIA_60_MD5='36ca08b712639088b27300ef5d6348e0'
 ARCHIVE_BASE_UTOPIA_60_SIZE='75007'
 ARCHIVE_BASE_UTOPIA_60_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_UTOPIA_60_URL='https://www.gog.com/game/stellaris_utopia'
 
 ARCHIVE_BASE_UTOPIA_59_NAME='stellaris_utopia_3_14_1592653_81105.sh'
 ARCHIVE_BASE_UTOPIA_59_MD5='ce44b8d0f9afa3e05927c914d1033341'
@@ -142,11 +145,16 @@ ARCHIVE_BASE_UTOPIA_17_VERSION='3.0.3-gog47193'
 
 ## Apocalypse
 
+ARCHIVE_BASE_APOCALYPSE_51_NAME='stellaris_apocalypse_4_1_7_86266.sh'
+ARCHIVE_BASE_APOCALYPSE_51_MD5='a90f4847dbb8019b661e3272b681624e'
+ARCHIVE_BASE_APOCALYPSE_51_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_51_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_APOCALYPSE_51_URL='https://www.gog.com/game/stellaris_apocalypse'
+
 ARCHIVE_BASE_APOCALYPSE_50_NAME='stellaris_apocalypse_4_0_23_84679.sh'
 ARCHIVE_BASE_APOCALYPSE_50_MD5='657e28499f3f9c7e7e46446b1f45bab0'
 ARCHIVE_BASE_APOCALYPSE_50_SIZE='37877'
 ARCHIVE_BASE_APOCALYPSE_50_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_APOCALYPSE_50_URL='https://www.gog.com/game/stellaris_apocalypse'
 
 ARCHIVE_BASE_APOCALYPSE_49_NAME='stellaris_apocalypse_3_14_1592653_81105.sh'
 ARCHIVE_BASE_APOCALYPSE_49_MD5='7f21a52edafc0c8a80e97a947dc5afa6'
@@ -225,11 +233,16 @@ ARCHIVE_BASE_APOCALYPSE_7_VERSION='3.0.3-gog47193'
 
 ## MegaCorp
 
+ARCHIVE_BASE_MEGACORP_48_NAME='stellaris_megacorp_4_1_7_86266.sh'
+ARCHIVE_BASE_MEGACORP_48_MD5='84550d6dd8bbdf1ad9f613029e25513a'
+ARCHIVE_BASE_MEGACORP_48_SIZE='90404'
+ARCHIVE_BASE_MEGACORP_48_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_MEGACORP_48_URL='https://www.gog.com/game/stellaris_megacorp'
+
 ARCHIVE_BASE_MEGACORP_47_NAME='stellaris_megacorp_4_0_23_84679.sh'
 ARCHIVE_BASE_MEGACORP_47_MD5='8e6ad615e3fa7a902e05f54c4e54564e'
 ARCHIVE_BASE_MEGACORP_47_SIZE='90404'
 ARCHIVE_BASE_MEGACORP_47_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_MEGACORP_47_URL='https://www.gog.com/game/stellaris_megacorp'
 
 ARCHIVE_BASE_MEGACORP_46_NAME='stellaris_megacorp_3_14_1592653_81105.sh'
 ARCHIVE_BASE_MEGACORP_46_MD5='897bda9d1e5eda534a4913245e3af69b'
@@ -308,11 +321,16 @@ ARCHIVE_BASE_MEGACORP_4_VERSION='3.0.3-gog47193'
 
 ## Federations
 
+ARCHIVE_BASE_FEDERATIONS_43_NAME='stellaris_federations_4_1_7_86266.sh'
+ARCHIVE_BASE_FEDERATIONS_43_MD5='e66ebe87313965d25ae63721636e3bad'
+ARCHIVE_BASE_FEDERATIONS_43_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_43_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_FEDERATIONS_43_URL='https://www.gog.com/game/stellaris_federations'
+
 ARCHIVE_BASE_FEDERATIONS_42_NAME='stellaris_federations_4_0_23_84679.sh'
 ARCHIVE_BASE_FEDERATIONS_42_MD5='432adf7d8b2491d1810d1fc7182f7806'
 ARCHIVE_BASE_FEDERATIONS_42_SIZE='14433'
 ARCHIVE_BASE_FEDERATIONS_42_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_FEDERATIONS_42_URL='https://www.gog.com/game/stellaris_federations'
 
 ARCHIVE_BASE_FEDERATIONS_41_NAME='stellaris_federations_3_14_1592653_81105.sh'
 ARCHIVE_BASE_FEDERATIONS_41_MD5='ce2828f957f35b1ce114c1bf66fa65c2'
@@ -381,11 +399,16 @@ ARCHIVE_BASE_FEDERATIONS_1_VERSION='3.2.2-gog51685'
 
 ## Nemesis
 
+ARCHIVE_BASE_NEMESIS_30_NAME='stellaris_nemesis_4_1_7_86266.sh'
+ARCHIVE_BASE_NEMESIS_30_MD5='9a7e29858a771521a8e6b792191df98f'
+ARCHIVE_BASE_NEMESIS_30_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_30_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_NEMESIS_30_URL='https://www.gog.com/game/stellaris_nemesis'
+
 ARCHIVE_BASE_NEMESIS_29_NAME='stellaris_nemesis_4_0_23_84679.sh'
 ARCHIVE_BASE_NEMESIS_29_MD5='dad4d0666016994358fcacb23c64e018'
 ARCHIVE_BASE_NEMESIS_29_SIZE='38539'
 ARCHIVE_BASE_NEMESIS_29_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_NEMESIS_29_URL='https://www.gog.com/game/stellaris_nemesis'
 
 ARCHIVE_BASE_NEMESIS_28_NAME='stellaris_nemesis_3_14_1592653_81105.sh'
 ARCHIVE_BASE_NEMESIS_28_MD5='7d686008bc3b604c55578cb7b72b711b'
@@ -434,11 +457,16 @@ ARCHIVE_BASE_NEMESIS_0_VERSION='3.6.1-gog60754'
 
 ## Overlord
 
+ARCHIVE_BASE_OVERLORD_25_NAME='stellaris_overlord_4_1_7_86266.sh'
+ARCHIVE_BASE_OVERLORD_25_MD5='38622d832b353aee6dbb9956b5e145fc'
+ARCHIVE_BASE_OVERLORD_25_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_25_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_OVERLORD_25_URL='https://www.gog.com/game/stellaris_overlord'
+
 ARCHIVE_BASE_OVERLORD_24_NAME='stellaris_overlord_4_0_23_84679.sh'
 ARCHIVE_BASE_OVERLORD_24_MD5='9a854138d0831c661965036719252902'
 ARCHIVE_BASE_OVERLORD_24_SIZE='99860'
 ARCHIVE_BASE_OVERLORD_24_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_OVERLORD_24_URL='https://www.gog.com/game/stellaris_overlord'
 
 ARCHIVE_BASE_OVERLORD_23_NAME='stellaris_overlord_3_14_1592653_81105.sh'
 ARCHIVE_BASE_OVERLORD_23_MD5='b556024c88c3d9dec03c8e5945de49b4'
@@ -482,11 +510,16 @@ ARCHIVE_BASE_OVERLORD_2_VERSION='3.8.4.1-gog65337'
 
 ## Galactic Paragons
 
+ARCHIVE_BASE_PARAGONS_25_NAME='stellaris_galactic_paragons_4_1_7_86266.sh'
+ARCHIVE_BASE_PARAGONS_25_MD5='e246e9d897591d9e7b549991cad29721'
+ARCHIVE_BASE_PARAGONS_25_SIZE='832'
+ARCHIVE_BASE_PARAGONS_25_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_PARAGONS_25_URL='https://www.gog.com/game/stellaris_galactic_paragons'
+
 ARCHIVE_BASE_PARAGONS_24_NAME='stellaris_galactic_paragons_4_0_23_84679.sh'
 ARCHIVE_BASE_PARAGONS_24_MD5='c32dc8e5ece651f47c1e585b4ea98e5c'
 ARCHIVE_BASE_PARAGONS_24_SIZE='832'
 ARCHIVE_BASE_PARAGONS_24_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_PARAGONS_24_URL='https://www.gog.com/game/stellaris_galactic_paragons'
 
 ARCHIVE_BASE_PARAGONS_23_NAME='stellaris_galactic_paragons_3_14_1592653_81105.sh'
 ARCHIVE_BASE_PARAGONS_23_MD5='b3a00f45cec93aea1ff6a2a0108935a5'
@@ -525,11 +558,16 @@ ARCHIVE_BASE_PARAGONS_2_VERSION='3.8.4.1-gog65337'
 
 ## Astral Planes
 
+ARCHIVE_BASE_PLANES_19_NAME='stellaris_astral_planes_4_1_7_86266.sh'
+ARCHIVE_BASE_PLANES_19_MD5='3a30613469053692aa74cfa1e7c4f1b5'
+ARCHIVE_BASE_PLANES_19_SIZE='46789'
+ARCHIVE_BASE_PLANES_19_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_PLANES_19_URL='https://www.gog.com/game/stellaris_astral_planes'
+
 ARCHIVE_BASE_PLANES_18_NAME='stellaris_astral_planes_4_0_23_84679.sh'
 ARCHIVE_BASE_PLANES_18_MD5='e34bcde8db82137627e7bccaca471be5'
 ARCHIVE_BASE_PLANES_18_SIZE='46789'
 ARCHIVE_BASE_PLANES_18_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_PLANES_18_URL='https://www.gog.com/game/stellaris_astral_planes'
 
 ARCHIVE_BASE_PLANES_17_NAME='stellaris_astral_planes_3_14_1592653_81105.sh'
 ARCHIVE_BASE_PLANES_17_MD5='27e12dbda8a5734ec6bd94e6eda650d9'
@@ -558,11 +596,16 @@ ARCHIVE_BASE_PLANES_5_VERSION='3.10.4-gog70670'
 
 ## The Machine Age
 
+ARCHIVE_BASE_MACHINE_10_NAME='stellaris_the_machine_age_4_1_7_86266.sh'
+ARCHIVE_BASE_MACHINE_10_MD5='4877f30296d1be2b5a323e9f0e996f10'
+ARCHIVE_BASE_MACHINE_10_SIZE='100390'
+ARCHIVE_BASE_MACHINE_10_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_MACHINE_10_URL='https://www.gog.com/game/stellaris_the_machine_age'
+
 ARCHIVE_BASE_MACHINE_9_NAME='stellaris_the_machine_age_4_0_23_84679.sh'
 ARCHIVE_BASE_MACHINE_9_MD5='bd0a016b3974fa441665e2dcf89bb700'
 ARCHIVE_BASE_MACHINE_9_SIZE='100390'
 ARCHIVE_BASE_MACHINE_9_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_MACHINE_9_URL='https://www.gog.com/game/stellaris_the_machine_age'
 
 ARCHIVE_BASE_MACHINE_8_NAME='stellaris_the_machine_age_3_14_1592653_81105.sh'
 ARCHIVE_BASE_MACHINE_8_MD5='07b714aa18a9c9ff40f5fbf03cf59e2d'
@@ -581,11 +624,16 @@ ARCHIVE_BASE_MACHINE_3_VERSION='3.12.5-gog74193'
 
 ## Cosmic Storms
 
+ARCHIVE_BASE_STORMS_6_NAME='stellaris_cosmic_storms_4_1_7_86266.sh'
+ARCHIVE_BASE_STORMS_6_MD5='49216dcae8261a3f7f6fbc2a59bd3400'
+ARCHIVE_BASE_STORMS_6_SIZE='829'
+ARCHIVE_BASE_STORMS_6_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_STORMS_6_URL='https://www.gog.com/game/stellaris_cosmic_storms'
+
 ARCHIVE_BASE_STORMS_5_NAME='stellaris_cosmic_storms_4_0_23_84679.sh'
 ARCHIVE_BASE_STORMS_5_MD5='b34dac8b2fb7970f171a5ec9a07232e1'
 ARCHIVE_BASE_STORMS_5_SIZE='829'
 ARCHIVE_BASE_STORMS_5_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_STORMS_5_URL='https://www.gog.com/game/stellaris_cosmic_storms'
 
 ARCHIVE_BASE_STORMS_4_NAME='stellaris_cosmic_storms_3_14_1592653_81105.sh'
 ARCHIVE_BASE_STORMS_4_MD5='672c8bb0d4992b1e76f827fe351fb69a'
