@@ -8,18 +8,23 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250917.1
+script_version=20251120.3
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
 
+ARCHIVE_BASE_62_NAME='stellaris_4_1_7_86266.sh'
+ARCHIVE_BASE_62_MD5='173d5ab87955eaac9d504a95ecfa3966'
+ARCHIVE_BASE_62_SIZE='25274344'
+ARCHIVE_BASE_62_VERSION='4.1.7-gog86266'
+ARCHIVE_BASE_62_URL='https://www.gog.com/game/stellaris'
+
 ARCHIVE_BASE_61_NAME='stellaris_4_0_23_84679.sh'
 ARCHIVE_BASE_61_MD5='72012fb6ce1ecd9c729e3ceb04fbba2a'
 ARCHIVE_BASE_61_SIZE='22711133'
 ARCHIVE_BASE_61_VERSION='4.0.23-gog84679'
-ARCHIVE_BASE_61_URL='https://www.gog.com/game/stellaris'
 
 ARCHIVE_BASE_60_NAME='stellaris_3_14_1592653_81105.sh'
 ARCHIVE_BASE_60_MD5='1cc50dc7470ed4ddd58fc755e9cf3024'
@@ -104,10 +109,6 @@ CONTENT_GAME_BIN_FILES='
 crash_reporter
 tools
 stellaris'
-CONTENT_GAME_DATA_MODELS_SHIPS_FILES='
-gfx/models/ships'
-CONTENT_GAME_DATA_MODELS_FILES='
-gfx/models'
 CONTENT_GAME_DATA_FILES='
 common
 curated_save_games
@@ -126,13 +127,20 @@ map
 music
 prescripted_countries
 previewer_assets
-sound
 tweakergui_assets
 unchecked_defines
 ChangeLog.txt
 ChangeLogBlank.txt
 checksum_manifest.txt
 ThirdPartyLicenses.txt'
+CONTENT_GAME_DATA_SOUND_FILES='
+sound'
+CONTENT_GAME_DATA_MODELS_FILES='
+gfx/models'
+CONTENT_GAME_DATA_MODELS_SHIPS_FILES='
+gfx/models/ships'
+CONTENT_GAME_DATA_MODELS_SHIPS_MEGASTRUCTURES_FILES='
+gfx/models/ships/megastructures'
 CONTENT_GAME_MULTIPLAYER_FILES='
 launcher-assets
 livepp
@@ -154,6 +162,8 @@ APP_MAIN_ICON='gfx/exe_icon.bmp'
 
 PACKAGES_LIST='
 PKG_BIN
+PKG_DATA_SOUND
+PKG_DATA_MODELS_SHIPS_MEGASTRUCTURES
 PKG_DATA_MODELS_SHIPS
 PKG_DATA_MODELS
 PKG_DATA
@@ -170,7 +180,6 @@ libGL.so.1
 libm.so.6
 libpthread.so.0
 libresolv.so.2
-libSDL2-2.0.so.0
 libstdc++.so.6
 libuuid.so.1
 libX11.so.6
@@ -179,8 +188,12 @@ libz.so.1'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 PKG_DATA_DEPENDENCIES_SIBLINGS='
+PKG_DATA_SOUND
 PKG_DATA_MODELS'
 
+PKG_DATA_SOUND_ID="${PKG_DATA_ID}-sound"
+PKG_DATA_SOUND_DESCRIPTION="${PKG_DATA_DESCRIPTION} - sound"
+
 PKG_DATA_MODELS_ID="${PKG_DATA_ID}-models"
 PKG_DATA_MODELS_DESCRIPTION="${PKG_DATA_DESCRIPTION} - models"
 PKG_DATA_MODELS_DEPENDENCIES_SIBLINGS='
@@ -188,6 +201,11 @@ PKG_DATA_MODELS_SHIPS'
 
 PKG_DATA_MODELS_SHIPS_ID="${PKG_DATA_MODELS_ID}-ships"
 PKG_DATA_MODELS_SHIPS_DESCRIPTION="${PKG_DATA_MODELS_DESCRIPTION} - ships"
+PKG_DATA_MODELS_SHIPS_DEPENDENCIES_SIBLINGS='
+PKG_DATA_MODELS_SHIPS_MEGASTRUCTURES'
+
+PKG_DATA_MODELS_SHIPS_MEGASTRUCTURES_ID="${PKG_DATA_MODELS_SHIPS_ID}-megastructures"
+PKG_DATA_MODELS_SHIPS_MEGASTRUCTURES_DESCRIPTION="${PKG_DATA_MODELS_SHIPS_DESCRIPTION} - megastructures"
 
 PKG_MULTIPLAYER_ID="${GAME_ID}-multiplayer"
 PKG_MULTIPLAYER_DESCRIPTION='Paradox launcher'
@@ -247,8 +265,17 @@ content_inclusion_default
 ## Force the use of system-provided SDL.
 APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
 $(launcher_tweak_sdl_override)"
+PKG_BIN_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES
+libSDL2-2.0.so.0"
+## Prevent a crash with SDL3 when music should be played.
+## cf. https://github.com/libsdl-org/sdl2-compat/issues/548
+APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')
+# Prevent a crash with SDL3 when music should be played.
+# cf. https://github.com/libsdl-org/sdl2-compat/issues/548
+export SDL2COMPAT_BROKEN_LOADWAV_SIZE=1
+"
 
-launchers_generation 'PKG_BIN'
+launchers_generation
 
 # Build packages.
 
