@@ -5,20 +5,20 @@
 set -o errexit
 
 ###
-# The Elder Scrolls 3
+# The Elder Scrolls 3: Morrowind
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241121.1
+script_version=20250928.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='the-elder-scrolls-3'
-GAME_NAME='The Elder Scrolls Ⅲ: Morrowind'
+GAME_NAME='The Elder Scrolls III: Morrowind'
 
 ARCHIVE_BASE_EN_1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(77582).exe'
 ARCHIVE_BASE_EN_1_MD5='c3ea7739b81d457e4c7d91758b762f4e'
-## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
+## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings.
 ARCHIVE_BASE_EN_1_EXTRACTOR='innoextract'
 ARCHIVE_BASE_EN_1_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_EN_1_PART1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(77582)-1.bin'
@@ -29,7 +29,6 @@ ARCHIVE_BASE_EN_1_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_
 
 ARCHIVE_BASE_FR_1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(french)_(77582).exe'
 ARCHIVE_BASE_FR_1_MD5='5f56a00e9256d930f63ab677c43c8b75'
-## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
 ARCHIVE_BASE_FR_1_EXTRACTOR='innoextract'
 ARCHIVE_BASE_FR_1_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_FR_1_PART1_NAME='setup_the_elder_scrolls_iii_morrowind_goty_1.6.0.1820_gog_0.1_(french)_(77582)-1.bin'
@@ -40,7 +39,6 @@ ARCHIVE_BASE_FR_1_URL='https://www.gog.com/game/the_elder_scrolls_iii_morrowind_
 
 ARCHIVE_BASE_EN_0_NAME='setup_tes_morrowind_goty_2.0.0.7.exe'
 ARCHIVE_BASE_EN_0_MD5='3a027504a0e4599f8c6b5b5bcc87a5c6'
-## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
 ARCHIVE_BASE_EN_0_EXTRACTOR='innoextract'
 ARCHIVE_BASE_EN_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_EN_0_SIZE='2300000'
@@ -48,7 +46,6 @@ ARCHIVE_BASE_EN_0_VERSION='1.6.1820-gog2.0.0.7'
 
 ARCHIVE_BASE_FR_0_NAME='setup_tes_morrowind_goty_french_2.0.0.7.exe'
 ARCHIVE_BASE_FR_0_MD5='2aee024e622786b2cb5454ff074faf9b'
-## Do not convert file paths to lowercase, as it causes problems when importing morrowind.ini default settings
 ARCHIVE_BASE_FR_0_EXTRACTOR='innoextract'
 ARCHIVE_BASE_FR_0_EXTRACTOR_OPTIONS=' '
 ARCHIVE_BASE_FR_0_SIZE='2300000'
@@ -62,11 +59,24 @@ Morrowind.ini
 Data Files/BookArt
 Data Files/Sound/Vo
 Data Files/Splash
-Data Files/Video
-Data Files/*.bsa
-Data Files/*.esm'
+Data Files/Video/bethesda logo.bik
+Data Files/Video/mw_*.bik
+Data Files/Morrowind.bsa
+Data Files/Morrowind.esm'
+CONTENT_GAME_EXPANSION_TRIBUNAL_FILES='
+Data Files/Tribunal.bsa
+Data Files/Tribunal.esm'
+CONTENT_GAME_EXPANSION_BLOODMOON_FILES='
+Data Files/Video/bm_*.bik
+Data Files/Bloodmoon.bsa
+Data Files/Bloodmoon.esm'
 CONTENT_GAME_DATA_FILES='
-Data Files
+Data Files/Fonts
+Data Files/Icons
+Data Files/Meshes
+Data Files/Music
+Data Files/Sound
+Data Files/Textures
 Knife.ico'
 CONTENT_GAME_DATAFILES_DATA_RELATIVE_PATH='_OfficialPlugins/_unpacked_files'
 CONTENT_GAME_DATAFILES_DATA_FILES='
@@ -87,7 +97,9 @@ APP_MAIN_ICON='Morrowind.exe'
 PACKAGES_LIST='
 PKG_BIN
 PKG_L10N
-PKG_DATA'
+PKG_DATA
+PKG_EXPANSION_TRIBUNAL
+PKG_EXPANSION_BLOODMOON'
 
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_L10N_BASE
@@ -107,6 +119,26 @@ PKG_L10N_DESCRIPTION_FR='French localization'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
+PKG_EXPANSION_TRIBUNAL_ID="${GAME_ID}-tribunal"
+PKG_EXPANSION_TRIBUNAL_ID_FR="${PKG_EXPANSION_TRIBUNAL_ID}-fr"
+PKG_EXPANSION_TRIBUNAL_ID_EN="${PKG_EXPANSION_TRIBUNAL_ID}-en"
+PKG_EXPANSION_TRIBUNAL_PROVIDES="
+$PKG_EXPANSION_TRIBUNAL_ID"
+PKG_EXPANSION_TRIBUNAL_DESCRIPTION='Tribunal expansion'
+PKG_EXPANSION_TRIBUNAL_DEPENDENCIES_SIBLINGS='
+PKG_BIN
+PKG_L10N'
+
+PKG_EXPANSION_BLOODMOON_ID="${GAME_ID}-bloodmoon"
+PKG_EXPANSION_BLOODMOON_ID_FR="${PKG_EXPANSION_BLOODMOON_ID}-fr"
+PKG_EXPANSION_BLOODMOON_ID_EN="${PKG_EXPANSION_BLOODMOON_ID}-en"
+PKG_EXPANSION_BLOODMOON_PROVIDES="
+$PKG_EXPANSION_BLOODMOON_ID"
+PKG_EXPANSION_BLOODMOON_DESCRIPTION='Bloodmoon expansion'
+PKG_EXPANSION_BLOODMOON_DEPENDENCIES_SIBLINGS='
+PKG_BIN
+PKG_L10N'
+
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -133,11 +165,11 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 (
@@ -162,13 +194,13 @@ archive_extraction_default
 	esac
 )
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion 'GAME_DATAFILES_DATA' 'PKG_DATA' "$(path_game_data)/Data Files"
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
 custom_launcher() {
 	launcher_headers
@@ -201,14 +233,14 @@ custom_launcher() {
 	exit 0
 	OUTEREOF
 }
-launchers_generation 'PKG_BIN'
+launchers_generation
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
