@@ -11,9 +11,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241228.1
+script_version=20251113.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='tomb-raider-remastered-1-2-3'
 GAME_NAME='Tomb Raider I-III Remastered'
@@ -28,28 +28,31 @@ ARCHIVE_BASE_0_VERSION='1.01-gog77558'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/tomb_raider_i_to_iii_remastered'
 
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_BIN_FILES='
-tomb123.exe
+## The game crashes on launch if any of the following libraries is missing.
+CONTENT_LIBS_BIN_FILES='
 1/tomb1.dll
 2/tomb2.dll
 3/tomb3.dll'
-CONTENT_GAME_DATA_1_FILES='
-1'
-CONTENT_GAME_DATA_2_FILES='
-2'
-CONTENT_GAME_DATA_3_FILES='
-3'
+CONTENT_GAME_BIN_FILES='
+tomb123.exe'
+CONTENT_GAME_DATA_FILES='
+?/cuts
+?/data
+?/fmv
+?/item
+?/pix
+?/sfx
+?/tex
+?/text
+?/tracks'
 
 WINE_PERSISTENT_DIRECTORIES='
-users/$[USER}/AppData/Roaming/TRX'
+users/${USER}/AppData/Roaming/TRX'
 
 APP_MAIN_EXE='tomb123.exe'
 
 PACKAGES_LIST='
 PKG_BIN
-PKG_DATA_1
-PKG_DATA_2
-PKG_DATA_3
 PKG_DATA'
 
 PKG_BIN_ARCH='64'
@@ -57,19 +60,14 @@ PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
-PKG_DATA_1_ID="${PKG_DATA_ID}-episode-1"
-PKG_DATA_2_ID="${PKG_DATA_ID}-episode-2"
-PKG_DATA_3_ID="${PKG_DATA_ID}-episode-3"
 PKG_DATA_DESCRIPTION='data'
-PKG_DATA_1_DESCRIPTION="$PKG_DATA_DESCRIPTION - Episode 1"
-PKG_DATA_2_DESCRIPTION="$PKG_DATA_DESCRIPTION - Episode 2"
-PKG_DATA_3_DESCRIPTION="$PKG_DATA_DESCRIPTION - Episode 3"
-PKG_DATA_DEPENDENCIES_SIBLINGS='
-PKG_DATA_1
-PKG_DATA_2
-PKG_DATA_3'
+## Easier upgrades from pre-20251113.1 packages
+PKG_DATA_PROVIDES='
+tomb-raider-remastered-1-2-3-data-episode-1
+tomb-raider-remastered-1-2-3-data-episode-2
+tomb-raider-remastered-1-2-3-data-episode-3'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -95,29 +93,44 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
