@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Transistor
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241229.1
+script_version=20250721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='transistor'
 GAME_NAME='Transistor'
@@ -69,10 +70,16 @@ Newtonsoft.Json.xml
 CONTENT_DOC_MAIN_FILES='
 Linux.README'
 
-## TODO: Check why a regular symlinks prefix can not be used
-APP_MAIN_PREFIX_TYPE='none'
 APP_MAIN_EXE='Transistor.exe'
 APP_MAIN_ICON='Transistor.bmp'
+## If the Content/Movies/*.bik files are symbolic links, the game crashes when trying to load them.
+APP_MAIN_PRERUN='
+# Prevent a crash due to the inability of libBink.so to properly handle symbolic links.
+if [ -d Content/Movies ]; then
+	rm --recursive Content/Movies
+	ln --symbolic "${PATH_GAME_DATA}/Content/Movies" Content/Movies
+fi
+'
 
 PACKAGES_LIST='
 PKG_MAIN
@@ -103,8 +110,6 @@ System.Xml.dll
 System.Xml.Linq.dll'
 
 PKG_LIBS_ID="${GAME_ID}-libs"
-PKG_LIBS64_ID="$PKG_LIBS_ID"
-PKG_LIBS32_ID="$PKG_LIBS_ID"
 PKG_LIBS64_ARCH='64'
 PKG_LIBS32_ARCH='32'
 PKG_LIBS_DEPENDENCIES_LIBRARIES='
@@ -115,8 +120,6 @@ libm.so.6
 libpthread.so.0
 librt.so.1
 libstdc++.so.6'
-PKG_LIBS64_DEPENDENCIES_LIBRARIES="$PKG_LIBS_DEPENDENCIES_LIBRARIES"
-PKG_LIBS32_DEPENDENCIES_LIBRARIES="$PKG_LIBS_DEPENDENCIES_LIBRARIES"
 
 # Load common functions
 
@@ -159,6 +162,13 @@ content_inclusion_default
 
 # Write launchers
 
+## This game expects an executable stack through dynamically loaded libraries.
+game_exec_line() {
+	cat <<- 'EOF'
+	GLIBC_TUNABLES=glibc.rtld.execstack=2 mono Transistor.exe "$@"
+	EOF
+}
+
 launchers_generation 'PKG_MAIN'
 
 # Build packages
