@@ -9,7 +9,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250828.2
+script_version=20251112.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -124,19 +124,57 @@ ARCHIVE_BASE_GOG_EN_0_VERSION='1.2-gog11362'
 CONTENT_PATH_DEFAULT_DOTEMU='.'
 CONTENT_PATH_DEFAULT_GOG='.'
 CONTENT_PATH_DEFAULT_GOG_EN_0='app'
-CONTENT_GAME_BIN_FILES='
-bin
-vampire/dlls
-vampire/cl_dlls
+## The game fails to launch if any of the following libraries is missing.
+CONTENT_LIBS_BIN_FILES='
+bin/launcher.dll
+bin/filesystem_stdio.dll
+bin/materialsystem.dll
+bin/engine.dll
+bin/vgui2.dll
+bin/vguimatsurface.dll
+bin/shaderapidx9.dll
+bin/VPHYSICS.DLL
+bin/StudioRender.dll
+vampire/cl_dlls/GameUI.dll'
+## loader.dll is only used by the GOG build.
+CONTENT_LIBS_BIN_FILES_GOG="$CONTENT_LIBS_BIN_FILES
+loader.dll"
+## launcher.dll requirements
+CONTENT_LIBS0_BIN_FILES='
+bin/vstdlib.dll
+bin/tier0.dll'
+## engine.dll requirements
+CONTENT_LIBS1_BIN_FILES='
+bin/binkw32.dll
+bin/vampire_python21.dll'
+## The game crashes after an initial loading screen if the following library is missing.
+CONTENT_LIBS2_BIN_FILES='
+bin/vaudio_miles.dll'
+## vaudio_miles.dll requirements
+CONTENT_LIBS3_BIN_FILES='
+bin/mss32.dll'
+## The game errors out after an initial loading screen if the following library is missing.
+CONTENT_LIBS4_BIN_FILES='
+vampire/cl_dlls/client.dll'
+## The game menu is displayed as wireframe if any of the following libraries is missing.
+CONTENT_LIBS5_BIN_FILES='
+bin/stdshader_dx6.dll
+bin/stdshader_dx7.dll
+bin/stdshader_dx8.dll
+bin/stdshader_dx9.dll'
+## The game crashes when trying to start a new game if the following library is missing.
+CONTENT_LIBS6_BIN_FILES='
+vampire/dlls/vampire.dll'
+CONTENT_GAME_BIN_FILES_DOTEMU='
+bin/mssmp3.asi
+bin/mssvoice.asi
+vampire.exe'
+CONTENT_GAME_BIN_FILES_GOG='
+bin/loader
+bin/mssmp3.asi
+bin/mssvoice.asi
 loader.exe
-vampire.exe
-vampire.exe.12
-dbghelp.dll
-loader.dll'
-## This configuration file is created by the current game script,
-## cf. "Give access to character histories (backgrounds)"
-CONTENT_GAME0_BIN_FILES='
-vampire/cfg/config.cfg'
+vampire.exe'
 ## These paths are created at the "Extract game data" step.
 CONTENT_GAME_L10N_EN_PATH_DOTEMU='l10n-en'
 CONTENT_GAME_L10N_FR_PATH_DOTEMU='l10n-fr'
@@ -189,25 +227,16 @@ vampire/vidcfg.bin'
 WINE_VIRTUAL_DESKTOP='auto'
 
 APP_MAIN_EXE_DOTEMU='vampire.exe'
-## Using vampire.exe directly with the GOG build leads to lingering processes
+## Using vampire.exe directly with the GOG build leads to lingering processes.
 ## cf. https://bugs.winehq.org/show_bug.cgi?id=56713
-## Vampire: The Masquerade - Bloodlines Vampire.exe process keeps lingering
+## (WINE 9.9)
 APP_MAIN_EXE_GOG='loader.exe'
 APP_MAIN_ICON='vampire.exe'
-## Work around the deletion of zlib1.dll
-## (WINE 10.0)
-APP_MAIN_PRERUN='
-# Work around the deletion of zlib1.dll
-system_library="${WINEPREFIX}/drive_c/windows/system32/zlib1.dll"
-if [ ! -e "$system_library" ]; then
-	cp "bin/zlib1.dll" "$system_library"
-fi
-'
 ## Keep hold of the terminal until the game process actually ends,
-## instead of returning as soon as the game is started
+## instead of returning as soon as the game is started.
 APP_MAIN_POSTRUN='
 # Keep hold of the terminal until the game process actually ends,
-# instead of returning as soon as the game is started
+# instead of returning as soon as the game is started.
 sleep 10s
 pidwait --euid "$USER" --ignore-case vampire.exe
 '
@@ -251,7 +280,7 @@ REQUIREMENTS_LIST_DOTEMU='
 unzip
 convmv'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -277,18 +306,18 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+case "$(current_archive)" in
+	('ARCHIVE_BASE_DOTEMU_'*)
+		(
+			cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_DOTEMU_'*)
 			localized_paths='
 			Docs
 			Vampire/pack101.vpk
@@ -313,12 +342,9 @@ archive_extraction_default
 			rm "$(archive_path 'ARCHIVE_EN')"
 			## Localized paths are moved out of the way to prevent them from being overwritten.
 			mkdir 'l10n-en'
-			## Silence a ShellCheck false positive, word splitting is expected here
-			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			## Silence a ShellCheck false positive, word splitting is expected here.
 			# shellcheck disable=SC2086
 			cp --link --parents --recursive $localized_paths_en 'l10n-en'
-			## Silence a ShellCheck false positive, word splitting is expected here
-			## SC2086 (info): Double quote to prevent globbing and word splitting.
 			# shellcheck disable=SC2086
 			rm --recursive $localized_paths
 	
@@ -327,37 +353,50 @@ archive_extraction_default
 			rm "$(archive_path 'ARCHIVE_FR')"
 			## Localized paths are moved out of the way to prevent them from being overwritten.
 			mkdir 'l10n-fr'
-			## Silence a ShellCheck false positive, word splitting is expected here
-			## SC2086 (info): Double quote to prevent globbing and word splitting.
+			## Silence a ShellCheck false positive, word splitting is expected here.
 			# shellcheck disable=SC2086
 			cp --link --parents --recursive $localized_paths_fr 'l10n-fr'
-			## Silence a ShellCheck false positive, word splitting is expected here
-			## SC2086 (info): Double quote to prevent globbing and word splitting.
 			# shellcheck disable=SC2086
 			rm --recursive $localized_paths
 
 			tolower .
-		;;
-	esac
-
-	# Give access to character histories (backgrounds).
-	config_file='vampire/cfg/config.cfg'
-	mkdir --parents "$(dirname "$config_file")"
-	cat > "$config_file" <<- EOF
-	vchar_edit_histories "1"
-	EOF
-)
+		)
+	;;
+esac
 
 # Include game data
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Give access to character histories (backgrounds).
 
-launchers_generation 'PKG_BIN'
+config_file="$(package_path 'PKG_BIN')$(path_game_data)/vampire/cfg/config.cfg"
+mkdir --parents "$(dirname "$config_file")"
+cat > "$config_file" <<- EOF
+vchar_edit_histories "1"
+EOF
 
-# Build packages
+# Write launchers.
+
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
+	EOF
+	cat <<- 'EOF'
+	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
+		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
+	    mkdir --parents "$(dirname "$dll_destination")"
+	    ln --symbolic "$dll_source" "$dll_destination"
+	done
+	EOF
+}
+
+launchers_generation
+
+# Build packages.
 
 packages_generation
 case "$(current_archive)" in
@@ -385,7 +424,7 @@ case "$(current_archive)" in
 	;;
 esac
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
