@@ -13,9 +13,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250427.1
+script_version=20250820.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='war-for-the-overworld'
 GAME_NAME='War for the Overworld'
@@ -39,11 +39,16 @@ EXPANSION_NAME_SEASONALWORKER='Seasonal Worker Skins'
 
 ## Underlord Edition
 
+ARCHIVE_BASE_UNDERLORD_10_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_3f1_82000.sh'
+ARCHIVE_BASE_UNDERLORD_10_MD5='5b2a56f4ce9f3d2895a90c12321db8ca'
+ARCHIVE_BASE_UNDERLORD_10_SIZE='1048'
+ARCHIVE_BASE_UNDERLORD_10_VERSION='2.1.3f1-gog82000'
+ARCHIVE_BASE_UNDERLORD_10_URL='https://www.gog.com/game/war_for_the_overworld_underlord_edition_upgrade'
+
 ARCHIVE_BASE_UNDERLORD_9_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_3_81115.sh'
 ARCHIVE_BASE_UNDERLORD_9_MD5='5eac82814fdebfba78d4370a4b0519d6'
 ARCHIVE_BASE_UNDERLORD_9_SIZE='1048'
 ARCHIVE_BASE_UNDERLORD_9_VERSION='2.1.3-gog81115'
-ARCHIVE_BASE_UNDERLORD_9_URL='https://www.gog.com/game/war_for_the_overworld_underlord_edition_upgrade'
 
 ARCHIVE_BASE_UNDERLORD_8_NAME='war_for_the_overworld_underlord_edition_upgrade_v2_1_2_76431.sh'
 ARCHIVE_BASE_UNDERLORD_8_MD5='c214676919d7475a5dc2558ab8481b2e'
@@ -82,11 +87,16 @@ ARCHIVE_BASE_UNDERLORD_2_VERSION='2.0.5-gog24177'
 
 ## Founders Theme
 
+ARCHIVE_BASE_FOUNDERS_5_NAME='war_for_the_overworld_founders_theme_charity_v2_1_3f1_82000.sh'
+ARCHIVE_BASE_FOUNDERS_5_MD5='1bac55d944657ebf1fe2532620d6c27c'
+ARCHIVE_BASE_FOUNDERS_5_SIZE='1048'
+ARCHIVE_BASE_FOUNDERS_5_VERSION='2.1.3f1-gog82000'
+ARCHIVE_BASE_FOUNDERS_5_URL='http://buy.wftogame.com/charity/'
+
 ARCHIVE_BASE_FOUNDERS_4_NAME='war_for_the_overworld_founders_theme_charity_v2_1_3_81115.sh'
 ARCHIVE_BASE_FOUNDERS_4_MD5='a80bb2ec79ec76ff3187bbcabba83732'
 ARCHIVE_BASE_FOUNDERS_4_SIZE='1048'
 ARCHIVE_BASE_FOUNDERS_4_VERSION='2.1.3-gog81115'
-ARCHIVE_BASE_FOUNDERS_4_URL='http://buy.wftogame.com/charity/'
 
 ARCHIVE_BASE_FOUNDERS_3_NAME='war_for_the_overworld_founders_theme_charity_v2_1_2_76431.sh'
 ARCHIVE_BASE_FOUNDERS_3_MD5='5d3a4a047ff40d4d6aede45bc92241a5'
@@ -110,11 +120,16 @@ ARCHIVE_BASE_FOUNDERS_0_VERSION='2.0.7f1-gog36563'
 
 ## Kickstarter Theme
 
+ARCHIVE_BASE_KICKSTARTER_5_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_3f1_82000.sh'
+ARCHIVE_BASE_KICKSTARTER_5_MD5='290e2f1c26d55b5b7cf4bf5c7d7ade18'
+ARCHIVE_BASE_KICKSTARTER_5_SIZE='1048'
+ARCHIVE_BASE_KICKSTARTER_5_VERSION='2.1.3f1-gog82000'
+ARCHIVE_BASE_KICKSTARTER_5_URL='http://buy.wftogame.com/charity/'
+
 ARCHIVE_BASE_KICKSTARTER_4_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_3_81115.sh'
 ARCHIVE_BASE_KICKSTARTER_4_MD5='d19a49bf32c6686d82ba4d0a2ebddd26'
 ARCHIVE_BASE_KICKSTARTER_4_SIZE='1048'
 ARCHIVE_BASE_KICKSTARTER_4_VERSION='2.1.3-gog81115'
-ARCHIVE_BASE_KICKSTARTER_4_URL='http://buy.wftogame.com/charity/'
 
 ARCHIVE_BASE_KICKSTARTER_3_NAME='war_for_the_overworld_kickstarter_theme_charity_v2_1_2_76431.sh'
 ARCHIVE_BASE_KICKSTARTER_3_MD5='e5f937fe8b8b2b323d06e7b77c579d45'
@@ -138,11 +153,16 @@ ARCHIVE_BASE_KICKSTARTER_0_VERSION='2.0.7f1-gog36563'
 
 ## The Cynical Imp
 
+ARCHIVE_BASE_CYNICAL_5_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_3f1_82000.sh'
+ARCHIVE_BASE_CYNICAL_5_MD5='e3f3d7b831cdfb26504f547ad30eb031'
+ARCHIVE_BASE_CYNICAL_5_SIZE='1048'
+ARCHIVE_BASE_CYNICAL_5_VERSION='2.1.3f1-gog82000'
+ARCHIVE_BASE_CYNICAL_5_URL='http://buy.wftogame.com/charity/'
+
 ARCHIVE_BASE_CYNICAL_4_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_3_81115.sh'
 ARCHIVE_BASE_CYNICAL_4_MD5='2d9da5fc41705b70bbda8dd2ae382ea6'
 ARCHIVE_BASE_CYNICAL_4_SIZE='1048'
 ARCHIVE_BASE_CYNICAL_4_VERSION='2.1.3-gog81115'
-ARCHIVE_BASE_CYNICAL_4_URL='http://buy.wftogame.com/charity/'
 
 ARCHIVE_BASE_CYNICAL_3_NAME='war_for_the_overworld_cynical_imp_charity_v2_1_2_76431.sh'
 ARCHIVE_BASE_CYNICAL_3_MD5='39148177572cbb5a953eede826816cf7'
@@ -166,11 +186,16 @@ ARCHIVE_BASE_CYNICAL_0_VERSION='2.0.7f1-gog36563'
 
 ## Seasonal Worker Skins
 
+ARCHIVE_BASE_SEASONALWORKER_6_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_3f1_82000.sh'
+ARCHIVE_BASE_SEASONALWORKER_6_MD5='4dfe007a692e95d9a47a5110e6a2fee5'
+ARCHIVE_BASE_SEASONALWORKER_6_SIZE='1048'
+ARCHIVE_BASE_SEASONALWORKER_6_VERSION='2.1.3f1-gog82000'
+ARCHIVE_BASE_SEASONALWORKER_6_URL='https://www.gog.com/game/war_for_the_overworld_worker_skin_collection'
+
 ARCHIVE_BASE_SEASONALWORKER_5_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_3_81115.sh'
 ARCHIVE_BASE_SEASONALWORKER_5_MD5='6b99c1003b6712b50cf0e77afbbb951c'
 ARCHIVE_BASE_SEASONALWORKER_5_SIZE='1048'
 ARCHIVE_BASE_SEASONALWORKER_5_VERSION='2.1.3-gog81115'
-ARCHIVE_BASE_SEASONALWORKER_5_URL='https://www.gog.com/game/war_for_the_overworld_worker_skin_collection'
 
 ARCHIVE_BASE_SEASONALWORKER_4_NAME='war_for_the_overworld_seasonal_worker_skins_v2_1_2_76431.sh'
 ARCHIVE_BASE_SEASONALWORKER_4_MD5='941ee4e1fd7a37a9862f79054bbb8b00'
