@@ -9,12 +9,12 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241124.1
+script_version=20251024.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='warcraft-3'
-GAME_NAME='Warcraft Ⅲ'
+GAME_NAME='Warcraft III'
 
 EXPANSION_ID='the-frozen-throne'
 EXPANSION_NAME='The Frozen Throne'
@@ -107,10 +107,10 @@ PKG_DATA_SHARED_DESCRIPTION='data shared between the base game and the expansion
 
 # Set the list of requirements to extract the archive contents.
 
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-smpq"
+REQUIREMENTS_LIST='
+smpq'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -136,7 +136,7 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
@@ -154,7 +154,7 @@ archive_initialize_required \
 	'ARCHIVE_CDKEY' \
 	'ARCHIVE_REQUIRED_CDKEY'
 
-# Extract game data
+# Extract game data.
 
 archive_path=$(archive_path "$(current_archive)")
 archive_path_cdkey=$(archive_path 'ARCHIVE_CDKEY')
@@ -181,21 +181,29 @@ information_archive_data_extraction "$archive_path"
 	)
 )
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
