@@ -8,12 +8,12 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241124.1
+script_version=20251025.5
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='warcraft-3'
-GAME_NAME='Warcraft Ⅲ: Reign of Chaos'
+GAME_NAME='Warcraft III: Reign of Chaos'
 
 ARCHIVE_BASE_EN_0_NAME='Installer Tome.mpq'
 ARCHIVE_BASE_EN_0_MD5='dd5926d8bb6ed10c47617bbc69b0ce1a'
@@ -34,14 +34,22 @@ ARCHIVE_BASE_DE_0_VERSION='1.27-blizzard1'
 ARCHIVE_BASE_DE_0_URL='https://eu.battle.net/download/getLegacy?os=win&locale=deDE&product=WAR3'
 
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_BIN_PATH='PC'
+CONTENT_LIBS_BIN_PATH='PC'
+CONTENT_LIBS_BIN_FILES='
+Game.dll
+ijl15.dll
+mss32.dll
+Storm.dll'
 ## Warcraft III.exe and World Editor.exe are distinct between the English and the French build of the game,
 ## for now we assume the differences are not critical and one can be used in place of the other.
+CONTENT_GAME_BIN_PATH='PC'
 CONTENT_GAME_BIN_FILES='
 redist
 blizzard.ax
-*.dll
-*.exe'
+War3.exe
+Warcraft III.exe
+WorldEdit.exe
+World Editor.exe'
 CONTENT_GAME_DATA_PATH='Common'
 CONTENT_GAME_DATA_FILES='
 Maps
@@ -94,10 +102,10 @@ PKG_DATA_SHARED_DESCRIPTION='data shared between the base game and the expansion
 
 # Set the list of requirements to extract the archive contents.
 
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-smpq"
+REQUIREMENTS_LIST='
+smpq'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -123,7 +131,7 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
@@ -146,7 +154,7 @@ archive_initialize_required \
 	'ARCHIVE_CDKEY_2' \
 	'ARCHIVE_REQUIRED_CDKEY_2'
 
-# Extract game data
+# Extract game data.
 
 archive_path=$(archive_path "$(current_archive)")
 archive_path_cdkey_1=$(archive_path 'ARCHIVE_CDKEY_1')
@@ -157,9 +165,9 @@ information_archive_data_extraction "$archive_path"
 	cd "${PLAYIT_WORKDIR}/gamedata"
 	smpq --extract "$archive_path"
 
-	# Update the .mpq file
+	# Update the .mpq file.
 	(
-		## Ensure case consistency between the different builds of the game
+		## Ensure case consistency between the different builds of the game.
 		cd 'Common'
 		if [ -e 'war3.mpq' ]; then
 			mv 'war3.mpq' 'War3.mpq'
@@ -183,21 +191,29 @@ information_archive_data_extraction "$archive_path"
 	)
 )
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
