@@ -13,7 +13,7 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250713.1
+script_version=20251101.7
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -32,8 +32,6 @@ GAME_NAME_DC="$GAME_NAME - Dark Crusade"
 GAME_ID_SS="${GAME_ID}-soulstorm"
 GAME_NAME_SS="$GAME_NAME - Soulstorm"
 
-# Archives
-
 ## Dawn of War (base game)
 
 ARCHIVE_BASE_DOW_EN_0_NAME='setup_warhammer_40000_dawn_of_war_0.19_(64626).exe'
@@ -162,46 +160,56 @@ ARCHIVE_BASE_SS_FR_0_PART2_MD5='6ba9d30068b91823d838812c8930c8b3'
 ARCHIVE_BASE_SS_FR_0_SIZE='5500000'
 ARCHIVE_BASE_SS_FR_0_VERSION='1.2.0-gog64626'
 
-
 CONTENT_PATH_DEFAULT='.'
+## w40k.exe / w40kwa.exe requirements
+CONTENT_LIBS_BIN_FILES='
+BugSplat.dll
+DivxMediaLib.dll
+Debug.dll
+Filesystem.dll
+Localizer.dll
+LuaConfig.dll
+MathBox.dll
+Memory.dll
+Platform.dll
+seInterface.dll
+UserInterface.dll
+Util.dll
+GSLobby.dll
+SimEngine.dll
+Galaxy.dll'
+## winterassault.exe (demo) requirements
+CONTENT_LIBS_BIN_FILES_WA_DEMO='
+LuaConfig.dll
+Debug.dll
+STLPort.dll
+Util.dll
+GSLobby.dll
+seInterface.dll
+Platform.dll
+DivxMediaLib.dll
+Localizer.dll
+UserInterface.dll
+MathBox.dll
+Memory.dll
+SimEngine.dll
+Filesystem.dll'
+## DivxMediaLib.dll requirements
+CONTENT_LIBS0_BIN_FILES='
+FileParser.dll
+DivxDecoder.dll'
+## The game fails to start with a GPU-related error if the following library is missing.
+CONTENT_LIBS1_BIN_FILES='
+spdx9.dll'
+## The game fails to reach the main menu if the following libraries are missing.
+CONTENT_LIBS2_BIN_FILES='
+W40kMod.dll
+WXPMod.dll'
+## W40kMod.dll / WXPMod.dll requirements
+CONTENT_LIBS3_BIN_FILES='
+luabind.dll'
 CONTENT_GAME_BIN_FILES='
 bugreport
-bugsplat.dll
-bugsplatrc.dll
-dbghelp.dll
-debug.dll
-divxdecoder.dll
-divxmedialib.dll
-dlltie.dll
-dsetup.dll
-dsetup32.dll
-dxtc.dll
-fileparser.dll
-filesystem.dll
-gslobby.dll
-ijl15.dll
-localizer.dll
-luabind.dll
-luaconfig.dll
-mathbox.dll
-memory.dll
-netconfig.dll
-patch.dll
-platform.dll
-plathook.dll
-profiler.dll
-seinterface.dll
-simengine.dll
-spdx9.dll
-stlport.dll
-symsrv.dll
-userinterface.dll
-util.dll
-w40kmod.dll
-wxpmod.dll
-mfc??.dll
-msvcp??.dll
-msvcr??.dll
 bssndrpt.exe
 darkcrusade.exe
 graphicsconfig.exe
@@ -211,9 +219,6 @@ w40kwa.exe
 winterassault.exe
 local.ini
 w40k.ini'
-## With GOG builds, the game binary is linked against Galaxy.dll.
-CONTENT_GAME0_BIN_FILES='
-galaxy.dll'
 CONTENT_GAME_L10N_FILES='
 bugreport/english
 bugreport/french
@@ -266,88 +271,64 @@ APP_MAIN_ICON_WRESTOOL_OPTIONS_WA_DEMO='--type=14'
 ## or it will be wrongly identified as a Mono application.
 APP_MAIN_TYPE='wine'
 
-# Packages
-
 PACKAGES_LIST='
 PKG_L10N
 PKG_BIN
 PKG_DATA'
 
-PKG_L10N_DESCRIPTION_EN='English localization'
-PKG_L10N_DESCRIPTION_FR='French localization'
-
 PKG_BIN_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_L10N_BASE
 PKG_DATA'
 
-PKG_DATA_DESCRIPTION='data'
-
-## Dawn of War (base game)
-
 PKG_L10N_BASE_ID_DOW="${GAME_ID}-l10n"
+PKG_L10N_BASE_ID_WA="${GAME_ID_WA}-l10n"
+PKG_L10N_BASE_ID_WA_DEMO="${GAME_ID_WA_DEMO}-l10n"
+PKG_L10N_BASE_ID_DC="${GAME_ID_DC}-l10n"
+PKG_L10N_BASE_ID_SS="${GAME_ID_SS}-l10n"
 PKG_L10N_ID_DOW_EN="${PKG_L10N_BASE_ID_DOW}-en"
 PKG_L10N_ID_DOW_FR="${PKG_L10N_BASE_ID_DOW}-fr"
-PKG_L10N_PROVIDES_DOW="
-$PKG_L10N_BASE_ID_DOW"
-PKG_L10N_DESCRIPTION_DOW_EN="$PKG_L10N_DESCRIPTION_EN"
-PKG_L10N_DESCRIPTION_DOW_FR="$PKG_L10N_DESCRIPTION_FR"
-
-PKG_DATA_ID_DOW="${GAME_ID}-data"
-
-## Winter Assault (full game)
-
-PKG_L10N_BASE_ID_WA="${GAME_ID_WA}-l10n"
 PKG_L10N_ID_WA_EN="${PKG_L10N_BASE_ID_WA}-en"
 PKG_L10N_ID_WA_FR="${PKG_L10N_BASE_ID_WA}-fr"
-PKG_L10N_PROVIDES_WA="
-$PKG_L10N_BASE_ID_WA"
-PKG_L10N_DESCRIPTION_WA_EN="$PKG_L10N_DESCRIPTION_EN"
-PKG_L10N_DESCRIPTION_WA_FR="$PKG_L10N_DESCRIPTION_FR"
-
-PKG_DATA_ID_WA="${GAME_ID_WA}-data"
-
-## Winter Assault (free demo)
-
-PKG_L10N_BASE_ID_WA_DEMO="${GAME_ID_WA_DEMO}-l10n"
 PKG_L10N_ID_WA_DEMO_EN="${PKG_L10N_BASE_ID_WA_DEMO}-en"
-PKG_L10N_PROVIDES_WA_DEMO="
-$PKG_L10N_BASE_ID_WA_DEMO"
-PKG_L10N_DESCRIPTION_WA_DEMO_EN="$PKG_L10N_DESCRIPTION_EN"
-
-PKG_DATA_ID_WA_DEMO="${GAME_ID_WA_DEMO}-data"
-
-## Dark Crusade
-
-PKG_L10N_BASE_ID_DC="${GAME_ID_DC}-l10n"
 PKG_L10N_ID_DC_EN="${PKG_L10N_BASE_ID_DC}-en"
 PKG_L10N_ID_DC_FR="${PKG_L10N_BASE_ID_DC}-fr"
-PKG_L10N_PROVIDES_DC="
-$PKG_L10N_BASE_ID_DC"
-PKG_L10N_DESCRIPTION_DC_EN="$PKG_L10N_DESCRIPTION_EN"
-PKG_L10N_DESCRIPTION_DC_FR="$PKG_L10N_DESCRIPTION_FR"
-
-PKG_DATA_ID_DC="${GAME_ID_DC}-data"
-
-## Soulstorm
-
-PKG_L10N_BASE_ID_SS="${GAME_ID_SS}-l10n"
 PKG_L10N_ID_SS_EN="${PKG_L10N_BASE_ID_SS}-en"
 PKG_L10N_ID_SS_FR="${PKG_L10N_BASE_ID_SS}-fr"
+PKG_L10N_PROVIDES_DOW="
+$PKG_L10N_BASE_ID_DOW"
+PKG_L10N_PROVIDES_WA="
+$PKG_L10N_BASE_ID_WA"
+PKG_L10N_PROVIDES_WA_DEMO="
+$PKG_L10N_BASE_ID_WA_DEMO"
+PKG_L10N_PROVIDES_DC="
+$PKG_L10N_BASE_ID_DC"
 PKG_L10N_PROVIDES_SS="
 $PKG_L10N_BASE_ID_SS"
-PKG_L10N_DESCRIPTION_SS_EN="$PKG_L10N_DESCRIPTION_EN"
-PKG_L10N_DESCRIPTION_SS_FR="$PKG_L10N_DESCRIPTION_FR"
+PKG_L10N_DESCRIPTION_DOW_EN='English localisation'
+PKG_L10N_DESCRIPTION_DOW_FR='French localisation'
+PKG_L10N_DESCRIPTION_WA_EN='English localisation'
+PKG_L10N_DESCRIPTION_WA_FR='French localisation'
+PKG_L10N_DESCRIPTION_WA_DEMO_EN='English localisation'
+PKG_L10N_DESCRIPTION_DC_EN='English localisation'
+PKG_L10N_DESCRIPTION_DC_FR='French localisation'
+PKG_L10N_DESCRIPTION_SS_EN='English localisation'
+PKG_L10N_DESCRIPTION_SS_FR='French localisation'
 
+PKG_DATA_ID_DOW="${GAME_ID}-data"
+PKG_DATA_ID_WA="${GAME_ID_WA}-data"
+PKG_DATA_ID_WA_DEMO="${GAME_ID_WA_DEMO}-data"
+PKG_DATA_ID_DC="${GAME_ID_DC}-data"
 PKG_DATA_ID_SS="${GAME_ID_SS}-data"
+PKG_DATA_DESCRIPTION='data'
 
 # Winter Assault (free demo)
 # - cabextract is required to extract the content of an inner archive
 # - unix2dos is required to generate a .ini file
 
-REQUIREMENTS_LIST_WA_DEMO="${REQUIREMENTS_LIST:-}
+REQUIREMENTS_LIST_WA_DEMO='
 cabextract
-unix2dos"
+unix2dos'
 
 # Load common functions
 
@@ -375,27 +356,26 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
+init_package() { set_default_package 'PKG_BIN'; }
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-## Winter Assault (free demo) - Extract game data from the cabinet installer.
+
+## Winter Assault (free demo)
 case "$(current_archive)" in
 	('ARCHIVE_BASE_WA_DEMO_'*)
+		## Extract game data from the cabinet installer.
 		ARCHIVE_INNER_PATH="${PLAYIT_WORKDIR}/gamedata/WinterAssaultDemo1.cab"
 		archive_extraction 'ARCHIVE_INNER'
 		rm "$ARCHIVE_INNER_PATH"
-	;;
-esac
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Winter Assault (free demo) - Create the expected game arborescence.
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_WA_DEMO_'*)
+		## Create the expected game arborescence.
+		(
+			cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 			mkdir --parents \
 				'badges' \
 				'banners' \
@@ -455,40 +435,43 @@ esac
 			mv 'wxpdatasharedtexturesfull.sga'  'wxp/wxpdata-sharedtextures-full.sga'
 			mv 'wxpdatasoundmed.sga'            'wxp/wxpdata-sound-med.sga'
 			mv 'wxpdatawhmmedium.sga'           'wxp/wxpdata-whm-medium.sga'
-		;;
-	esac
+		)
 
-	## Winter Assault (free demo) - Generate a required configuration file.
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_WA_DEMO_'*)
-			config_file="${PLAYIT_WORKDIR}/gamedata/regions.ini"
-			cat > "$config_file" <<- 'EOF'
-			[mods]
-			wxp=english
-			[global]
-			lang=english
-			EOF
-			unix2dos --quiet "$config_file"
-		;;
-	esac
-)
+		## Generate a required configuration file.
+		config_file="${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/regions.ini"
+		cat > "$config_file" <<- 'EOF'
+		[mods]
+		wxp=english
+		[global]
+		lang=english
+		EOF
+		unix2dos --quiet "$config_file"
+	;;
+esac
 
-
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
