@@ -5,20 +5,31 @@ set -o errexit
 
 ###
 # Warhammer 40k: Gladius
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241212.1
+script_version=20250603.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='warhammer-40k-gladius'
 GAME_NAME='Warhammer 40,000: Gladius - Relics of War'
 
+ARCHIVE_BASE_5_NAME='warhammer_40_000_gladius_relics_of_war_1_16_00_82313.sh'
+ARCHIVE_BASE_5_MD5='7c3795898a311ad274a4f061e4f6f0a4'
+ARCHIVE_BASE_5_SIZE='3679340'
+ARCHIVE_BASE_5_VERSION='1.16.0-gog82313'
+ARCHIVE_BASE_5_URL='https://www.gog.com/game/warhammer_40000_gladius_relics_of_war'
+
+ARCHIVE_BASE_4_NAME='warhammer_40_000_gladius_relics_of_war_1_15_01_78637.sh'
+ARCHIVE_BASE_4_MD5='47d39e7d60862615e6d65987049e40b0'
+ARCHIVE_BASE_4_SIZE='3607175'
+ARCHIVE_BASE_4_VERSION='1.15.1-gog78637'
+
 ARCHIVE_BASE_3_NAME='warhammer_40_000_gladius_relics_of_war_1_14_03_77940.sh'
 ARCHIVE_BASE_3_MD5='3d47d62522615fb42e876c630c5bbbb0'
 ARCHIVE_BASE_3_SIZE='3558407'
 ARCHIVE_BASE_3_VERSION='1.14.3-gog77940'
-ARCHIVE_BASE_3_URL='https://www.gog.com/game/warhammer_40000_gladius_relics_of_war'
 
 ARCHIVE_BASE_0_NAME='warhammer_40_000_gladius_relics_of_war_1_13_03_72014.sh'
 ARCHIVE_BASE_0_MD5='6ff6665c0a2ead9b1807fcddb28a9a08'
@@ -81,10 +92,17 @@ CONTENT_LIBS_BIN_FILES='
 libavcodec.so.58
 libavformat.so.58
 libavutil.so.56
+libboost_locale.so.1.74.0
+libboost_system.so.1.74.0
+libboost_thread.so.1.74.0
 libcrypto.so.1.1
 libEOSSDK-Linux-Shipping.so
+libicudata.so.60
+libicui18n.so.60
+libicuuc.so.60
 libjemalloc.so.1
 libjpeg.so.8
+libminiupnpc.so.17
 libnettle.so.6
 libswresample.so.3'
 ## Include libraries shipped with old game builds.
@@ -117,7 +135,29 @@ Resources
 *.doc
 *.pdf'
 
-## TODO: Check why a regular symlinks farm prefix can not be used
+## Running the game from a symlinks farm prefix leads to the following crash on launch:
+##
+## DataManager.hpp:100: T& proxy::core::DataManager<T>::get(const string&, bool) const [with T = proxy::video::Shader; std::string = std::__cxx11::basic_string<char>]: "Vertex/GUI" does not exist.
+## ExceptionHandler::handleException()
+## DataManager.hpp:100: T& proxy::core::DataManager<T>::get(const string&, bool) const [with T = proxy::video::Shader; std::string = std::__cxx11::basic_string<char>]: "Vertex/GUI" does not exist.
+## (0) [0x0x55ee9730627f] proxy::core::StackTrace::log() + 0x2f
+## (1) [0x0x55ee972a205c] proxy::core::ExceptionHandler::handleException() + 0x1c
+## (2) [0x0x7f15484b344a]  + 0xb344a
+## (3) [0x0x7f15484a15e9] std::unexpected() + 0
+## (4) [0x0x7f15484b36c8]  + 0xb36c8
+## (5) [0x0x55ee9613032f] void boost::throw_exception<boost::escaped_list_error>(boost::escaped_list_error const&, boost::source_location const&) + 0
+## (6) [0x0x55ee9627885e] proxy::core::DataManager<proxy::video::Shader>::get(std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > const&, bool) const + 0x1ee
+## (7) [0x0x55ee968090b1] proxy::video::Renderer::createSwapChain() + 0x1651
+## (8) [0x0x55ee9680a385] proxy::video::Renderer::initialize() + 0x3e5
+## (9) [0x0x55ee9679d03c] proxy::video::Display::createWindow(proxy::video::Display::Mode, proxy::video::Display::Resolution const&) + 0x93c
+## (10) [0x0x55ee9679fd49] proxy::video::Display::initialize(proxy::video::Display::Mode, proxy::video::Display::Resolution const&) + 0x29
+## (11) [0x0x55ee9629da1e] gladius::Game::initializeVideo() + 0xe8e
+## (12) [0x0x55ee962a0faa] gladius::Game::initialize(int, char**, char**) + 0x4a
+## (13) [0x0x55ee962344c2] gladius::Game::main(int, char**, char**) + 0x12
+## (14) [0x0x55ee96233af6] main + 0x36
+## (15) [0x0x7f154822eca8]  + 0x29ca8
+## (16) [0x0x7f154822ed65] __libc_start_main + 0x85
+## (17) [0x0x55ee9624712a] _start + 0x2a
 APP_MAIN_PREFIX_TYPE='none'
 APP_MAIN_EXE='Binaries/Linux-x86_64/Gladius.bin'
 APP_MAIN_ICON='Data/Video/Textures/Icon.png'
@@ -130,14 +170,12 @@ PKG_BIN_ARCH='64'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
 PKG_BIN_DEPENDENCIES_LIBRARIES='
-libboost_locale.so.1.74.0
 libc.so.6
 libcurl.so.4
 libdl.so.2
 libfreetype.so.6
 libgcc_s.so.1
 libglfw.so.3
-libminiupnpc.so.17
 libm.so.6
 libopenal.so.1
 libpng16.so.16
