@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Whispers of a Machine
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250110.1
+script_version=20250111.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='whispers-of-a-machine'
 GAME_NAME='Whispers of a Machine'
@@ -22,14 +23,10 @@ ARCHIVE_BASE_0_SIZE='768282'
 ARCHIVE_BASE_0_VERSION='1.0.6d-gog35876'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/whispers_of_a_machine'
 
+AGS_NAME='whispersofamachine'
+
 CONTENT_PATH_DEFAULT='.'
-CONTENT_GAME_MAIN_FILES='
-acsetup.cfg
-whispers.exe
-*.vox
-*.tra'
 
-APP_MAIN_SCUMMID='ags:whispersofamachine'
 APP_MAIN_ICON='whispers.exe'
 
 # Load common functions
