@@ -8,9 +8,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241125.1
+script_version=20251025.3
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='worms-2'
 GAME_NAME='Worms 2'
@@ -23,10 +23,23 @@ ARCHIVE_BASE_0_VERSION='1.05-gog2.0.0.23'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/worms_2'
 
 CONTENT_PATH_DEFAULT='app'
+## frontend.exe requirements
+CONTENT_LIBS_BIN_FILES='
+WIN32.dll'
+## WIN32.dll requirements
+CONTENT_LIBS0_BIN_FILES='
+libvorbisfile-3.dll'
+## libvorbisfile-3.dll requirements
+CONTENT_LIBS1_BIN_FILES='
+libogg-0.dll
+libvorbis-0.dll'
 CONTENT_GAME_BIN_FILES='
 binaries
-*.dll
-*.exe'
+frontend.exe
+goglauncher.exe
+start.exe
+worms2.exe
+data/wav/bankeditor.exe'
 CONTENT_GAME_DATA_FILES='
 data
 levels
@@ -56,9 +69,9 @@ data/*.dat'
 WINE_VIRTUAL_DESKTOP='640x480'
 
 APP_MAIN_EXE='frontend.exe'
-## Play the introduction videos on launch
+## Play the introduction videos on launch.
 APP_MAIN_PRERUN='
-# Play the introduction videos on launch
+# Play the introduction videos on launch.
 RANDOM_MOVIE=$(find . -mindepth 1 -maxdepth 1 -name "*.wmv" ! -name "intro.wmv" | shuf --head-count=1)
 mpv --fs --no-osc intro.wmv
 mpv --fs --no-osc "$RANDOM_MOVIE"
@@ -77,7 +90,7 @@ mpv'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -103,29 +116,37 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
-launchers_generation 'PKG_BIN'
+## Install shipped libraries.
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Install shipped libraries.
+	ln --force --symbolic $(path_libraries)/* "\${PATH_PREFIX}"
+	EOF
+}
 
-# Build packages
+launchers_generation
+
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
